<?php

namespace App\Http\Controllers;

use App\Models\CaseChild;
use App\Models\CaseChildMarried;
use App\Models\CaseExpenses;
use App\Models\CaseFather;
use App\Models\CaseIncome;
use App\Models\CaseMarketing;
use App\Models\CaseModel;
use App\Models\CaseMother;
use App\Models\CaseOther;
use App\Models\CaseProperty;
use Illuminate\Http\Request;
use PDF;

class CaseController extends Controller
{
    /**
     * Display a listing of the resource.
     */
    public function index()
    {
        $data = CaseModel::all();
        return view('admin.cases.index', compact('data'));
    }

    public function updateCases()
    {
        $data = CaseModel::whereNotNull('updated_case_date')->get();
        return view('admin.cases.update_list', compact('data'));
    }

    /**
     * Show the form for creating a new resource.
     */
    public function create()
    {
        return view('admin.cases.create');
    }

    /**
     * Store a newly created resource in storage.
     */
    public function store(Request $request)
    {
        $rules = [
            'case_type' => 'required|string|max:255',
            'name' => 'required|string|max:255',
            'parent_name' => 'required|string|max:255',
            'address' => 'required|string|max:255',
            'phone' => 'required|string|max:15', // Adjust max length for phone as needed
            'custom_id' => 'required|string|unique:cases,custom_id|max:255',
            'created_case_date' => 'required|date',
            'updated_case_date' => 'nullable|date',
        ];
        // Define custom Arabic error messages
        $messages = [
            'case_type.required' => 'نوع الدراسة مطلوب.',
            'name.required' => 'الاسم مطلوب.',
            'name.string' => 'الاسم يجب أن يكون نصياً.',
            'parent_name.required' => 'اسم ولي الأمر مطلوب.',
            'parent_name.string' => 'اسم ولي الأمر يجب أن يكون نصياً.',
            'address.required' => 'العنوان التفصيلي مطلوب.',
            'address.string' => 'العنوان التفصيلي يجب أن يكون نصياً.',
            'phone.required' => 'رقم الهاتف مطلوب.',
            'phone.string' => 'رقم الهاتف يجب أن يكون نصياً.',
            'phone.max' => 'رقم الهاتف يجب ألا يتجاوز 15 حرفاً.',
            'custom_id.required' => 'ترميز الدراسة مطلوب.',
            'custom_id.unique' => 'ترميز الدراسة يجب أن يكون فريداً.',
            'custom_id.string' => 'ترميز الدراسة يجب أن يكون نصياً.',
            'created_case_date.required' => 'تاريخ إجراء الدراسة مطلوب.',
            'created_case_date.date' => 'تاريخ إجراء الدراسة يجب أن يكون تاريخاً صحيحاً.',
            'updated_case_date.date' => 'تاريخ تحديث الدراسة المتوقع يجب أن يكون تاريخاً صحيحاً.',
        ];
        // Validate the request
        $validatedData = $request->validate($rules, $messages);

        // If validation passes, create a new case
        $case = CaseModel::create($validatedData);

        if($case){
            return redirect()->route('case.edit',['step' => 2, 'id' => $case->id]);
        }
    }

    /**
     * Display the specified resource.
     */
    public function show(string $id)
    {
        //
    }

    /**
     * Show the form for editing the specified resource.
     */
    public function edit(string $case_id)
    {
        $data = CaseModel::find($case_id);
        if (!$data) {
            return redirect()->back();
        } else {
            $step = $_GET["step"] ?? 1;
            switch ($step){
                case 1:
                    $title =  "تعديل دراسة الحالة";
                break;
                case 2:
                    $title =  "الأبناء";
                break;
                case 3:
                    $title =  "الأبناء المتزوجين";
                break;
                case 4:
                    $title =  "أخرون يعيشون مع الأسرة";
                break;
                case 5:
                    $title =  "معلومات الأب";
                break;
                case 6:
                    $title =  "معلومات الأم";
                break;
                case 7:
                    $title =  "ممتلكات الأسرة";
                break;
                case 8:
                    $title =  "الدراسة المالية";
                break;
                case 9:
                    $title =  "وصف الحالة";
                    break;
                default:
                    $title = 'دراسة الحالة';
                break;
            }
            return view('admin.cases.edit', compact('title','step', 'case_id', 'data'));
        }
    }

    /**
     * Update the specified resource in storage.
     */
    public function update(Request $request, string $id)
    {
        // Find the FamilyAid by ID
        $case = CaseModel::findOrFail($id);
        switch ($request->post('step')){
            case 1:
                return $this->handleStep1Edit($request, $case);
            break;
            case 2:
                return $this->handleStep2($request, $case);
            break;
            case 3:
                return $this->handleStep3($request, $case);
            break;
            case 4:
                return $this->handleStep4($request, $case);
            break;
            case 5:
                return $this->handleStep5($request, $case);
            break;
            case 6:
                return $this->handleStep6($request, $case);
            break;
            case 7:
                return $this->handleStep7($request, $case);
            break;
            case 8:
                return $this->handleStep8($request, $case);
            break;
            case 9:
                return $this->handleStep9($request, $case);
            break;
            default:
                return $this->handleStep1Edit($request, $case);
            break;
        }
    }

    public function handleStep1Edit(Request $request, $case)
    {
        $rules = [
            'case_type' => 'required|string|max:255',
            'name' => 'required|string|max:255',
            'parent_name' => 'required|string|max:255',
            'address' => 'required|string|max:255',
            'phone' => 'required|string|max:15', // Adjust max length for phone as needed
            'custom_id' => 'required|string|max:255|unique:cases,custom_id,' . $case->id,
            'created_case_date' => 'required|date',
            'updated_case_date' => 'nullable|date',
        ];
        // Define custom Arabic error messages
        $messages = [
            'case_type.required' => 'نوع الدراسة مطلوب.',
            'name.required' => 'الاسم مطلوب.',
            'name.string' => 'الاسم يجب أن يكون نصياً.',
            'parent_name.required' => 'اسم ولي الأمر مطلوب.',
            'parent_name.string' => 'اسم ولي الأمر يجب أن يكون نصياً.',
            'address.required' => 'العنوان التفصيلي مطلوب.',
            'address.string' => 'العنوان التفصيلي يجب أن يكون نصياً.',
            'phone.required' => 'رقم الهاتف مطلوب.',
            'phone.string' => 'رقم الهاتف يجب أن يكون نصياً.',
            'phone.max' => 'رقم الهاتف يجب ألا يتجاوز 15 حرفاً.',
            'custom_id.required' => 'ترميز الدراسة مطلوب.',
            'custom_id.unique' => 'ترميز الدراسة يجب أن يكون فريداً.',
            'custom_id.string' => 'ترميز الدراسة يجب أن يكون نصياً.',
            'created_case_date.required' => 'تاريخ إجراء الدراسة مطلوب.',
            'created_case_date.date' => 'تاريخ إجراء الدراسة يجب أن يكون تاريخاً صحيحاً.',
            'updated_case_date.date' => 'تاريخ تحديث الدراسة المتوقع يجب أن يكون تاريخاً صحيحاً.',
        ];
        // Validate the request
        $validatedData = $request->validate($rules, $messages);

        // If validation passes, create a new case
        $case->update($validatedData);

        if($case){
            return redirect()->route('case.edit',['step' => 2, 'id' => $case->id]);
        }
    }

    public function handleStep2(Request $request, $case)
    {
        // Validation rules
        $rules = [
            'case_id' => 'required|integer|exists:cases,id',
            'name.*' => 'required|string|max:255', // Validate each name in the array
            'birth_date.*' => 'required|date', // Validate each birth_date in the array
            'academic_status.*' => 'nullable|string|max:255', // Validate each academic_status in the array
            'health_status.*' => 'required|string|max:255', // Validate each health_status in the array
            'income.*' => 'nullable|integer|min:0', // Validate each income in the array
            'work.*' => 'nullable|string|max:255', // Validate each work in the array
        ];

        // Custom Arabic messages
        $messages = [
            'case_id.required' => 'رقم الحالة مطلوب.',
            'case_id.integer' => 'رقم الحالة يجب أن يكون رقماً.',
            'case_id.exists' => 'رقم الحالة غير موجود في النظام.',
            'name.*.required' => 'الاسم مطلوب.',
            'name.*.string' => 'الاسم يجب أن يكون نصياً.',
            'name.*.max' => 'الاسم يجب ألا يتجاوز 255 حرفاً.',
            'birth_date.*.required' => 'تاريخ الميلاد مطلوب.',
            'birth_date.*.date' => 'تاريخ الميلاد يجب أن يكون تاريخاً صحيحاً.',
            'academic_status.*.string' => 'الوضع الدراسي يجب أن تكون نصاً.',
            'academic_status.*.max' => 'الوضع الدراسي يجب ألا تتجاوز 255 حرفاً.',
            'health_status.*.required' => 'الوضع الصحي مطلوبة.',
            'health_status.*.string' => 'الوضع الصحي يجب أن تكون نصاً.',
            'health_status.*.max' => 'الوضع الصحي يجب ألا تتجاوز 255 حرفاً.',
            'income.*.integer' => 'الدخل يجب أن يكون رقماً.',
            'income.*.min' => 'الدخل يجب أن يكون صفراً أو أكبر.',
            'work.*.string' => 'العمل يجب أن يكون نصاً.',
            'work.*.max' => 'العمل يجب ألا يتجاوز 255 حرفاً.',
        ];

        // Validate the request
        $validatedData = $request->validate($rules, $messages);

        // Prepare data for insertion
        $childrenData = [];
        foreach ($request->input('name') as $index => $name) {
            $childrenData[] = [
                "id" => $request->input('child_id')[$index] ?? null,
                'case_id' => $request->input('case_id'),
                'name' => $name,
                'birth_date' => $request->input('birth_date')[$index],
                'academic_status' => $request->input('academic_status')[$index],
                'health_status' => $request->input('health_status')[$index],
                'income' => $request->input('income')[$index],
                'work' => $request->input('work')[$index],
            ];
        }

        foreach ($childrenData as $childrenDatum) {
            if($childrenDatum["id"]){
                $id = $childrenDatum["id"];
                unset($childrenDatum["id"]);
                CaseChild::where('id', $id)->update($childrenDatum);
            } else {
                CaseChild::create($childrenDatum);
            }
        }
        return redirect()->route('case.edit',['step' => 3, 'id' => $case->id]);
    }

    public function handleStep3(Request $request, $case)
    {
        // Validation rules
        $rules = [
            'case_id' => 'required|integer|exists:cases,id', // Ensure case_id exists in the cases table
            'name.*' => 'nullable|string|max:255', // Optional name with a maximum length of 255 characters
            'work.*' => 'nullable|string|max:255', // Optional work field
            'address.*' => 'nullable|string|max:255', // Optional address field
            'income.*' => 'nullable|integer|min:0', // Optional income, must be non-negative
            'children_count.*' => 'nullable|integer|min:0', // Optional children_count, must be non-negative
            'notes.*' => 'nullable|string|max:500', // Optional notes with a maximum length of 500 characters
        ];

        // Custom Arabic error messages
        $messages = [
            'case_id.required' => 'رقم الحالة مطلوب.',
            'case_id.integer' => 'رقم الحالة يجب أن يكون رقماً.',
            'case_id.exists' => 'رقم الحالة غير موجود في النظام.',
            'name.*.string' => 'الاسم يجب أن يكون نصاً.',
            'name.*.max' => 'الاسم يجب ألا يتجاوز 255 حرفاً.',
            'work.*.string' => 'العمل يجب أن يكون نصاً.',
            'work.*.max' => 'العمل يجب ألا يتجاوز 255 حرفاً.',
            'address.*.string' => 'السكن يجب أن يكون نصاً.',
            'address.*.max' => 'السكن يجب ألا يتجاوز 255 حرفاً.',
            'income.*.integer' => 'الدخل يجب أن يكون رقماً.',
            'income.*.min' => 'الدخل يجب ألا يكون أقل من صفر.',
            'children_count.*.integer' => 'عدد الأفراد يجب أن يكون رقماً.',
            'children_count.*.min' => 'عدد الأفراد يجب ألا يكون أقل من صفر.',
            'notes.*.string' => 'الملاحظات يجب أن تكون نصاً.',
            'notes.*.max' => 'الملاحظات يجب ألا تتجاوز 500 حرف.',
        ];

        // Validate the request
        $validatedData = $request->validate($rules, $messages);

        // Prepare data for insertion
        $childrenData = [];
        foreach ($request->input('name') as $index => $name) {
            $childrenData[] = [
                "id" => $request->input('child_id')[$index] ?? null,
                'case_id' => $request->input('case_id'),
                'name' => $name,
                'work' => $request->input('work')[$index],
                'address' => $request->input('address')[$index],
                'income' => $request->input('income')[$index],
                'children_count' => $request->input('children_count')[$index],
                'notes' => $request->input('notes')[$index],
            ];
        }

        foreach ($childrenData as $childrenDatum) {
            if($childrenDatum["id"]){
                $id = $childrenDatum["id"];
                unset($childrenDatum["id"]);
                CaseChildMarried::where('id', $id)->update($childrenDatum);
            } else {
                CaseChildMarried::create($childrenDatum);
            }
        }
        return redirect()->route('case.edit',['step' => 4, 'id' => $case->id]);
    }

    public function handleStep4(Request $request, $case)
    {
        // Validation rules
        $rules = [
            'case_id' => 'required|integer|exists:cases,id', // Ensure the case_id exists in the cases table
            'name.*' => 'nullable|string|max:255', // Optional name with max length of 255 characters
            'relationship.*' => 'nullable|string|max:255', // Optional relationship with max length of 255 characters
            'birth_date.*' => 'nullable|string', // Optional, must be a valid date
            'health_status.*' => 'nullable|string|max:255', // Optional health status with max length of 255 characters
            'note.*' => 'nullable|string|max:500', // Optional note with max length of 500 characters
        ];

        // Custom Arabic error messages
        $messages = [
            'case_id.required' => 'رقم الحالة مطلوب.',
            'case_id.integer' => 'رقم الحالة يجب أن يكون رقماً.',
            'case_id.exists' => 'رقم الحالة غير موجود في النظام.',
            'name.*.string' => 'الاسم يجب أن يكون نصاً.',
            'name.*.max' => 'الاسم يجب ألا يتجاوز 255 حرفاً.',
            'relationship.*.string' => 'العلاقة يجب أن تكون نصاً.',
            'relationship.*.max' => 'العلاقة يجب ألا تتجاوز 255 حرفاً.',
            'birth_date.*.string' => 'تاريخ الميلاد يجب أن يكون تاريخاً صحيحاً.',
            'health_status.*.string' => 'الوضع الصحي يجب أن يكون نصاً.',
            'health_status.*.max' => 'الوضع الصحي يجب ألا يتجاوز 255 حرفاً.',
            'note.*.string' => 'الملاحظات يجب أن تكون نصاً.',
            'note.*.max' => 'الملاحظات يجب ألا تتجاوز 500 حرف.',
        ];

        // Validate the request
        $validatedData = $request->validate($rules, $messages);

        // Prepare data for insertion
        $childrenData = [];
        foreach ($request->input('name') as $index => $name) {
            $childrenData[] = [
                "id" => $request->input('other_id')[$index] ?? null,
                'case_id' => $request->input('case_id'),
                'name' => $name,
                'relationship' => $request->input('relationship')[$index],
                'birth_date' => $request->input('birth_date')[$index],
                'health_status' => $request->input('health_status')[$index],
                'note' => $request->input('note')[$index],
            ];
        }

        foreach ($childrenData as $childrenDatum) {
            if($childrenDatum["id"]){
                $id = $childrenDatum["id"];
                unset($childrenDatum["id"]);
                CaseOther::where('id', $id)->update($childrenDatum);
            } else {
                CaseOther::create($childrenDatum);
            }
        }
        return redirect()->route('case.edit',['step' => 5, 'id' => $case->id]);
    }

    public function handleStep5(Request $request, $case)
    {
        $rules = [
            'father_id' => 'nullable',
            'case_id' => 'required|integer|exists:cases,id', // Ensure case_id exists in the cases table
            'father_name' => 'required|string|max:255',
            'father_nationality' => 'required|string|max:255',
            'father_national_id' => 'required|string|max:20',
            'father_birth_date' => 'nullable|date',
            'dad_academic_qualification' => 'required|string|max:255',
            'dad_dead_date' => 'nullable|date',
            'dad_cause_of_death' => 'nullable|string|max:255',
        ];
        // Define custom Arabic error messages
        $messages = [
            'case_id.required' => 'رقم الحالة مطلوب.',
            'case_id.integer' => 'رقم الحالة يجب أن يكون رقماً.',
            'case_id.exists' => 'رقم الحالة غير موجود في النظام.',
            'father_name.required' => 'اسم الأب مطلوب.',
            'father_name.string' => 'اسم الأب يجب أن يكون نصاً.',
            'father_name.max' => 'اسم الأب يجب ألا يتجاوز 255 حرفاً.',
            'father_nationality.required' => 'الجنسية مطلوبة.',
            'father_nationality.string' => 'الجنسية يجب أن تكون نصاً.',
            'father_nationality.max' => 'الجنسية يجب ألا تتجاوز 255 حرفاً.',
            'father_national_id.required' => 'الرقم الوطني للأب مطلوب.',
            'father_national_id.string' => 'الرقم الوطني يجب أن يكون نصاً.',
            'father_national_id.max' => 'الرقم الوطني يجب ألا يتجاوز 20 حرفاً.',
            'father_birth_date.date' => 'تاريخ ميلاد الأب يجب أن يكون تاريخاً صحيحاً.',
            'dad_academic_qualification.required' => 'المؤهل العلمي للأب مطلوب.',
            'dad_academic_qualification.string' => 'المؤهل العلمي يجب أن يكون نصاً.',
            'dad_academic_qualification.max' => 'المؤهل العلمي يجب ألا يتجاوز 255 حرفاً.',
            'dad_dead_date.date' => 'تاريخ الوفاة يجب أن يكون تاريخاً صحيحاً.',
            'dad_cause_of_death.string' => 'سبب الوفاة يجب أن يكون نصاً.',
            'dad_cause_of_death.max' => 'سبب الوفاة يجب ألا يتجاوز 255 حرفاً.',
        ];
        // Validate the request
        $validatedData = $request->validate($rules, $messages);

        // If validation passes, create a new case
        $caseFather = CaseFather::updateOrCreate(
            ['id' => $validatedData['father_id']], // Matching condition
            $validatedData // Data to update or create
        );

        if($caseFather){
            return redirect()->route('case.edit',['step' => 6, 'id' => $case->id]);
        }
    }

    public function handleStep6(Request $request, $case)
    {
        $rules = [
            'mother_id' => 'nullable',
            'case_id' => 'required|integer|exists:cases,id',
            'mother_name' => 'required|string|max:255',
            'mother_nationality' => 'required|string|max:255',
            'mother_national_id' => 'required|string|max:20',
            'mother_birth_date' => 'required|date',
            'mother_place_birth' => 'required|string|max:255',
            'mother_academic_qualification' => 'required|string|max:255',
            'mother_job_status' => 'required|string|max:255',
        ];
        // Define custom Arabic error messages
        $messages = [
            'case_id.required' => 'رقم الحالة مطلوب.',
            'case_id.integer' => 'رقم الحالة يجب أن يكون رقماً.',
            'case_id.exists' => 'رقم الحالة غير موجود في النظام.',
            'mother_name.required' => 'اسم الأم مطلوب.',
            'mother_name.string' => 'اسم الأم يجب أن يكون نصاً.',
            'mother_name.max' => 'اسم الأم يجب ألا يتجاوز 255 حرفاً.',
            'mother_nationality.required' => 'الجنسية مطلوبة.',
            'mother_nationality.string' => 'الجنسية يجب أن تكون نصاً.',
            'mother_nationality.max' => 'الجنسية يجب ألا تتجاوز 255 حرفاً.',
            'mother_national_id.required' => 'الرقم الوطني مطلوب.',
            'mother_national_id.string' => 'الرقم الوطني يجب أن يكون نصاً.',
            'mother_national_id.max' => 'الرقم الوطني يجب ألا يتجاوز 20 حرفاً.',
            'mother_birth_date.required' => 'تاريخ ميلاد الأم مطلوب.',
            'mother_birth_date.date' => 'تاريخ ميلاد الأم يجب أن يكون تاريخاً صحيحاً.',
            'mother_place_birth.required' => 'مكان ميلاد الأم مطلوب.',
            'mother_place_birth.string' => 'مكان الميلاد يجب أن يكون نصاً.',
            'mother_place_birth.max' => 'مكان الميلاد يجب ألا يتجاوز 255 حرفاً.',
            'mother_academic_qualification.required' => 'المؤهل العلمي للأم مطلوب.',
            'mother_academic_qualification.string' => 'المؤهل العلمي يجب أن يكون نصاً.',
            'mother_academic_qualification.max' => 'المؤهل العلمي يجب ألا يتجاوز 255 حرفاً.',
            'mother_job_status.required' => 'الحالة الوظيفية مطلوبة.',
            'mother_job_status.string' => 'الحالة الوظيفية يجب أن تكون نصاً.',
            'mother_job_status.max' => 'الحالة الوظيفية يجب ألا تتجاوز 255 حرفاً.',
        ];
        // Validate the request
        $validatedData = $request->validate($rules, $messages);

        // If validation passes, create a new case
        $caseMother = CaseMother::updateOrCreate(
            ['id' => $validatedData['mother_id']], // Matching condition
            $validatedData // Data to update or create
        );

        if($caseMother){
            return redirect()->route('case.edit',['step' => 7, 'id' => $case->id]);
        }
    }

    public function handleStep7(Request $request, $case)
    {
        $rules = [
            'property_id' => 'nullable',
            'case_id' => 'required|integer|exists:cases,id',
            'family_property_land' => 'required|string|max:255',
            'family_property_home' => 'required|string|max:255',
            'family_property_real_state' => 'required|string|max:255',
            'family_property_car' => 'required|string|max:255',
            'family_property_shop' => 'required|string|max:255',
        ];
        // Define custom Arabic error messages
        $messages = [
            'case_id.required' => 'رقم الحالة مطلوب.',
            'case_id.integer' => 'رقم الحالة يجب أن يكون رقماً.',
            'case_id.exists' => 'رقم الحالة غير موجود في النظام.',
            'family_property_land.required' => 'حقل الأراضي مطلوب.',
            'family_property_land.string' => 'حقل الأراضي يجب أن يكون نصاً.',
            'family_property_land.max' => 'حقل الأراضي يجب ألا يتجاوز 255 حرفاً.',
            'family_property_home.required' => 'حقل المنازل مطلوب.',
            'family_property_home.string' => 'حقل المنازل يجب أن يكون نصاً.',
            'family_property_home.max' => 'حقل المنازل يجب ألا يتجاوز 255 حرفاً.',
            'family_property_real_state.required' => 'حقل العقارات مطلوب.',
            'family_property_real_state.string' => 'حقل العقارات يجب أن يكون نصاً.',
            'family_property_real_state.max' => 'حقل العقارات يجب ألا يتجاوز 255 حرفاً.',
            'family_property_car.required' => 'حقل السيارات مطلوب.',
            'family_property_car.string' => 'حقل السيارات يجب أن يكون نصاً.',
            'family_property_car.max' => 'حقل السيارات يجب ألا يتجاوز 255 حرفاً.',
            'family_property_shop.required' => 'حقل المحلات التجارية مطلوب.',
            'family_property_shop.string' => 'حقل المحلات التجارية يجب أن يكون نصاً.',
            'family_property_shop.max' => 'حقل المحلات التجارية يجب ألا يتجاوز 255 حرفاً.',

        ];
        // Validate the request
        $validatedData = $request->validate($rules, $messages);

        // If validation passes, create a new case
        $caseProperty = CaseProperty::updateOrCreate(
            ['id' => $validatedData['property_id']], // Matching condition
            $validatedData // Data to update or create
        );

        if($caseProperty){
            return redirect()->route('case.edit',['step' => 8, 'id' => $case->id]);
        }
    }

    public function handleStep8(Request $request, $case)
    {
        // Validation rules
        $rules = [
            'case_id' => 'required|integer|exists:cases,id',
            'income_source.*' => 'required|string|max:255',
            'income_amount.*' => 'required|integer|min:0',
            'expenses_source.*' => 'required|string|max:255',
            'expenses_amount.*' => 'required|integer|min:0',
        ];

        // Custom Arabic error messages
        $messages = [
            'case_id.required' => 'رقم الحالة مطلوب.',
            'case_id.integer' => 'رقم الحالة يجب أن يكون رقماً.',
            'case_id.exists' => 'رقم الحالة غير موجود في النظام.',
            'income_source.*.required' => 'مصدر الدخل مطلوب.',
            'income_source.*.string' => 'مصدر الدخل يجب أن يكون نصاً.',
            'income_source.*.max' => 'مصدر الدخل يجب ألا يتجاوز 255 حرفاً.',
            'income_amount.*.required' => 'قيمة الدخل مطلوبة.',
            'income_amount.*.integer' => 'قيمة الدخل يجب أن تكون رقماً.',
            'income_amount.*.min' => 'قيمة الدخل يجب أن تكون صفراً أو أكثر.',
            'expenses_source.*.required' => 'مصدر المصروف مطلوب.',
            'expenses_source.*.string' => 'مصدر المصروف يجب أن يكون نصاً.',
            'expenses_source.*.max' => 'مصدر المصروف يجب ألا يتجاوز 255 حرفاً.',
            'expenses_amount.*.required' => 'قيمة المصروف مطلوبة.',
            'expenses_amount.*.integer' => 'قيمة المصروف يجب أن تكون رقماً.',
            'expenses_amount.*.min' => 'قيمة المصروف يجب أن تكون صفراً أو أكثر.',
        ];

        // Validate the request
        $validatedData = $request->validate($rules, $messages);

        // Prepare data for insertion
        $childrenData = [];
        foreach ($request->input('income_source') as $index => $name) {
            $childrenData[] = [
                "id" => $request->input('income_id')[$index] ?? null,
                'case_id' => $request->input('case_id'),
                'source' => $name,
                'amount' => $request->input('income_amount')[$index],
            ];
        }
        $childrenDataExpenses = [];
        foreach ($request->input('expenses_source') as $index => $name) {
            $childrenDataExpenses[] = [
                "id" => $request->input('expenses_id')[$index] ?? null,
                'case_id' => $request->input('case_id'),
                'source' => $name,
                'amount' => $request->input('expenses_amount')[$index],
            ];
        }

        foreach ($childrenData as $childrenDatum) {
            if($childrenDatum["id"]){
                $id = $childrenDatum["id"];
                unset($childrenDatum["id"]);
                CaseIncome::where('id', $id)->update($childrenDatum);
            } else {
                CaseIncome::create($childrenDatum);
            }
        }

        foreach ($childrenDataExpenses as $childrenDatum) {
            if($childrenDatum["id"]){
                $id = $childrenDatum["id"];
                unset($childrenDatum["id"]);
                CaseExpenses::where('id', $id)->update($childrenDatum);
            } else {
                CaseExpenses::create($childrenDatum);
            }
        }
        return redirect()->route('case.edit',['step' => 9, 'id' => $case->id]);
    }

    public function handleStep9(Request $request, $case)
    {
        $rules = [
            'case_desc' => 'required|string|max:1000',
        ];
        // Define custom Arabic error messages
        $messages = [
            'case_desc.required' => 'وصف الحالة مطلوب.',
            'case_desc.string' => 'وصف الحالة يجب أن يكون نصاً.',
            'case_desc.max' => 'وصف الحالة يجب ألا يتجاوز 1000 حرف.',
        ];
        // Validate the request
        $validatedData = $request->validate($rules, $messages);

        // If validation passes, create a new case
        $case->update($validatedData);

        if($case){
            return redirect()->route('case.index')->with('success', "تم الحفظ بنجاح");
        }
    }
    /**
     * Remove the specified resource from storage.
     */
    public function destroy(string $id)
    {
        //
    }

    public function update_status(Request $request)
    {
        if(isset($request->id)){
            $id = $request->id;
            $data = CaseModel::findOrFail($id);
            $data->status = $request->status;
            if ($data->save()) {
                if($request->status == 4){
                    $case_marketing = CaseMarketing::where("case_id", $request->id)->get();
                    if($case_marketing->count() <= 0){
                        $new_case_marketing = new CaseMarketing();
                        $new_case_marketing->case_id = $id;
                        $new_case_marketing->maximum_guarantee_value = $request->maximum_guarantee_value ?? null;
                        $new_case_marketing->priority = $request->priority ?? null;
                        $new_case_marketing->save();
                    }
                }
                echo json_encode(array("status" => "success"));
            } else {
                echo json_encode(array("status" => "failure"));
            }
        }
    }

    public function generatePdf($id)
    {
        $case = CaseModel::findOrFail($id);
        if($case){
            $pdf = PDF::loadView('pdf.study', ["data" => $case]);

            return $pdf->stream('document.pdf');
        }
    }
}
