<?php

namespace App\Http\Controllers;

use App\Models\CaseChild;
use App\Models\CaseMarketing;
use App\Models\CaseModel;
use App\Models\Donor;
use App\Models\Orphan;
use Illuminate\Http\Request;

class DonorController extends Controller
{
    /**
     * Display a listing of the resource.
     */
    public function index()
    {
        $data = Donor::all();
        return view('admin.donors.index', compact('data'));
    }

    /**
     * Show the form for creating a new resource.
     */
    public function create()
    {
        return view('admin.donors.create');
    }

    /**
     * Store a newly created resource in storage.
     */
    public function store(Request $request)
    {
        // Validation rules
        $rules = [
            'start_date_donation' => 'required|date',
            'donor_coding' => 'required|string|max:255',
            'name' => 'required|string|max:255',
            'qb_name' => 'required|string|max:255',
            'qb_id' => 'required|string|max:255',
            'payment_method' => 'required|string|max:255',
            'phone' => 'required|string|max:20',
            'amount' => 'required|numeric|min:0',
            'iban' => 'required|string|max:34',
            'status' => 'required|integer|in:0,1,3,4',
            'last_donation_date' => 'nullable|date',
            'children_count' => 'required|integer|min:0',
            'notes' => 'nullable|string|max:1000',
        ];

        // Custom Arabic validation messages
        $messages = [
            'start_date_donation.required' => 'تاريخ بدء الكفالة مطلوب.',
            'start_date_donation.date' => 'تاريخ بدء الكفالة يجب أن يكون تاريخًا صالحًا.',
            'donor_coding.required' => 'ترميز المتبرع مطلوب.',
            'name.required' => 'الإسم مطلوب.',
            'qb_name.required' => 'الإسم (QB) بوكس مطلوب.',
            'qb_id.required' => 'معرف (QB) بوكس مطلوب.',
            'payment_method.required' => 'طريقة الدفع مطلوبة.',
            'phone.required' => 'رقم الهاتف مطلوب.',
            'phone.max' => 'رقم الهاتف لا يمكن أن يتجاوز 20 حرفًا.',
            'amount.required' => 'المبلغ مطلوب.',
            'amount.numeric' => 'المبلغ يجب أن يكون رقمًا.',
            'amount.min' => 'المبلغ يجب أن يكون 0 أو أكثر.',
            'iban.required' => 'رقم الآيبان مطلوب.',
            'iban.max' => 'رقم الآيبان لا يمكن أن يتجاوز 34 حرفًا.',
            'status.required' => 'الحالة مطلوبة.',
            'status.in' => 'الحالة يجب أن تكون إما 0 (غير فعال) أو 1 (فعال).',
            'last_donation_date.date' => 'تاريخ اخر كفالة يجب أن يكون تاريخًا صالحًا.',
            'children_count.required' => 'عدد الأطفال مطلوب.',
            'children_count.integer' => 'عدد الأطفال يجب أن يكون رقمًا صحيحًا.',
            'children_count.min' => 'عدد الأطفال يجب أن يكون 0 أو أكثر.',
            'notes.string' => 'الملاحظات يجب أن تكون نصًا صالحًا.',
        ];

        // Validate the request
        $validated = $request->validate($rules, $messages);

        // Create the donor
        $donor = Donor::create($validated);

        if($donor){
            return redirect()->back()->with('success', "تم الإضافة بنجاح");
        }
    }



    /**
     * Display the specified resource.
     */
    public function show(string $id)
    {
        //
    }

    /**
     * Show the form for editing the specified resource.
     */
    public function edit(string $id)
    {
        $data = Donor::find($id);
        if (!$data) {
            return redirect()->back();
        } else {
            return view('admin.donors.edit', compact('data'));
        }
    }

    /**
     * Update the specified resource in storage.
     */
    public function update(Request $request, $id)
    {
        // Find the donor by ID
        $donor = Donor::findOrFail($id);

        // Validation rules
        $rules = [
            'start_date_donation' => 'required|date',
            'donor_coding' => 'required|string|max:255',
            'name' => 'required|string|max:255',
            'qb_name' => 'required|string|max:255',
            'qb_id' => 'required|string|max:255',
            'payment_method' => 'required|string|max:255',
            'phone' => 'required|string|max:20',
            'amount' => 'required|numeric|min:0',
            'iban' => 'required|string|max:34',
            'status' => 'required|integer|in:0,1,3,4',
            'last_donation_date' => 'nullable|date',
            'children_count' => 'required|integer|min:0',
            'notes' => 'nullable|string|max:1000',
        ];

        // Custom Arabic validation messages
        $messages = [
            'start_date_donation.required' => 'تاريخ بدء الكفالة مطلوب.',
            'start_date_donation.date' => 'تاريخ بدء الكفالة يجب أن يكون تاريخًا صالحًا.',
            'donor_coding.required' => 'ترميز المتبرع مطلوب.',
            'name.required' => 'الإسم مطلوب.',
            'qb_name.required' => 'الإسم (QB) بوكس مطلوب.',
            'qb_id.required' => 'معرف (QB) بوكس مطلوب.',
            'payment_method.required' => 'طريقة الدفع مطلوبة.',
            'phone.required' => 'رقم الهاتف مطلوب.',
            'phone.max' => 'رقم الهاتف لا يمكن أن يتجاوز 20 حرفًا.',
            'amount.required' => 'المبلغ مطلوب.',
            'amount.numeric' => 'المبلغ يجب أن يكون رقمًا.',
            'amount.min' => 'المبلغ يجب أن يكون 0 أو أكثر.',
            'iban.required' => 'رقم الآيبان مطلوب.',
            'iban.max' => 'رقم الآيبان لا يمكن أن يتجاوز 34 حرفًا.',
            'status.required' => 'الحالة مطلوبة.',
            'status.in' => 'الحالة يجب أن تكون إما 0 (غير فعال) أو 1 (فعال).',
            'last_donation_date.date' => 'تاريخ اخر كفالة يجب أن يكون تاريخًا صالحًا.',
            'children_count.required' => 'عدد الأطفال مطلوب.',
            'children_count.integer' => 'عدد الأطفال يجب أن يكون رقمًا صحيحًا.',
            'children_count.min' => 'عدد الأطفال يجب أن يكون 0 أو أكثر.',
            'notes.string' => 'الملاحظات يجب أن تكون نصًا صالحًا.',
        ];

        // Validate the request
        $validated = $request->validate($rules, $messages);

        // Update the donor with validated data
        $donor->update($validated);

        return redirect()->back()->with('success', 'تم التعديل بنجاح');
    }


    /**
     * Remove the specified resource from storage.
     */
    public function destroy(Donor $donor, Request $request)
    {
        $id = $request->id;
        $data = Donor::find($id)->delete();
        if ($data) {
            echo json_encode(array("status" => "success"));
        } else {
            echo json_encode(array("status" => "failure"));
        }
    }

    public function storeAndOrphan(Request $request)
    {
        // Validation rules
        $rules = [
            'start_date_donation' => 'required|date',
            'name' => 'required|string|max:255',
            'payment_method' => 'required|string|max:255',
            'phone' => 'required|string|max:20',
            'amount' => 'required|numeric|min:0',
            'iban' => 'required|string|max:34',
            'children_count' => 'required|integer|min:0',
        ];

        // Custom Arabic validation messages
        $messages = [
            'start_date_donation.required' => 'تاريخ بدء الكفالة مطلوب.',
            'start_date_donation.date' => 'تاريخ بدء الكفالة يجب أن يكون تاريخًا صالحًا.',
            'name.required' => 'الإسم مطلوب.',
            'payment_method.required' => 'طريقة الدفع مطلوبة.',
            'phone.required' => 'رقم الهاتف مطلوب.',
            'phone.max' => 'رقم الهاتف لا يمكن أن يتجاوز 20 حرفًا.',
            'amount.required' => 'المبلغ مطلوب.',
            'amount.numeric' => 'المبلغ يجب أن يكون رقمًا.',
            'amount.min' => 'المبلغ يجب أن يكون 0 أو أكثر.',
            'iban.required' => 'رقم الآيبان مطلوب.',
            'iban.max' => 'رقم الآيبان لا يمكن أن يتجاوز 34 حرفًا.',
            'children_count.required' => 'عدد الأطفال مطلوب.',
            'children_count.integer' => 'عدد الأطفال يجب أن يكون رقمًا صحيحًا.',
            'children_count.min' => 'عدد الأطفال يجب أن يكون 0 أو أكثر.',
        ];

        // Validate the request
        $validated = $request->validate($rules, $messages);
        $validated["case_id"] = $request->id;
        $donor = Donor::create($validated);

        if($donor){
            $id = $donor->id;
            $case = CaseModel::find($request->id);
            $children = CaseChild::where("case_id", $request->id)->get();
            $sum_for_donors = Donor::where("case_id", $request->id)->sum('amount');
            $new_amount = $case->marketing->maximum_guarantee_value - $request->amount;
            $case_marketing_update = CaseMarketing::where('case_id', $request->id)->update(['maximum_guarantee_value' => $new_amount]);

            if($sum_for_donors >= $case->marketing->maximum_guarantee_value){
                $number_for_child = $sum_for_donors / count($children);
                foreach ($children as $child) {
                    Orphan::create([
                        "custom_id" => $case->custom_id,
                        "child_name" => $child->name,
                        "mother_name" => $case->mother->mother_name,
                        "national_id" => $case->mother->mother_national_id,
                        "phone" => $case->phone,
                        "address" => $case->address,
                        "status" => 0,
                        "case_id" => $case->id,
                        "donor_id" => $id,
                        "sponsorship_start_date" => $request->start_date_donation,
                        "birthday" => $child->birth_date,
                        "bail_amount" => $number_for_child,
                        "orphan_type" => $case->case_type
                    ]);
                }
                CaseMarketing::where("case_id", $request->id)->update(["is_complete" => 1]);
            }
            echo json_encode(array("status" => "success"));
        } else {
            echo json_encode(array("status" => "failure"));
        }
    }
}
