<?php

namespace App\Http\Controllers;

use App\Models\Disbursement;
use App\Models\DisbursementItem;
use App\Models\Orphan;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Response;

class ExcelController extends Controller
{
    public function index()
    {
        $data = Disbursement::all();
        return view('admin.disbursement.index', compact('data'));
    }

    public function generate()
    {
        $month = date('m');
        $year = date('Y');
        $data = Orphan::where("status", 0)->get();
        return view('admin.disbursement.generate', compact('month', 'year', 'data'));
    }

    public function save()
    {
        $month = date('m');
        $year = date('Y');
        $data = Orphan::where("status", 0)->get();

        $total = 0;
        foreach ($data as $k => $v){
            $total = $v->bail_amount + $v->additional_amount;
        }

         $disbursement = Disbursement::create([
            'year' => $year,
            'month' => $month,
            'total' => $total,
        ]);

        foreach ($data as $k => $v) {
            DisbursementItem::create([
                'disbursement_id' => $disbursement->id,
                'orphan_id' => $v->id,
                'name' => $v->mother_name,
                'phone'=> $v->phone,
                'bail_amount' => $v->bail_amount,
                'additional_amount' => $v->additional_amount,
                'exchangeـnotes' => $v->exchangeـnotes,
            ]);
        }

        return redirect()->route('excel.show', [$disbursement->id]);
    }

    public function show($id)
    {
        $data = Disbursement::findOrFail($id);
        if($data){
            $title = "صرف ". $data->month."/".$data->year;
            return view('admin.disbursement.show', compact('data', 'title'));
        } else {
            return redirect()->back();
        }
    }

    public function downloadCSV($id)
    {
        $data = Disbursement::findOrFail($id);
        if($data) {
            $title = "صرف ". $data->month."-".$data->year;
            // Define the headers for the CSV
            $headers = [
                'Content-Type' => 'text/csv; charset=UTF-8',
                'Content-Disposition' => 'attachment; filename="'.$title.'.csv"',
            ];

            // Data to be written to the CSV
            $list = [
                ['#', 'الأسم', 'رقم الهاتف', 'مبلغ الكفالة', 'مبلغ اضافي', 'المجموع', 'ملاحظات الصرف'], // Header row
            ];

            foreach($data->items as $item){
                $list[] = [
                    $item->id,
                    $item->name,
                    $item->phone,
                    $item->bail_amount,
                    $item->additional_amount,
                    $item->bail_amount + $item->additional_amount,
                    $item->exchangeـnotes
                ];
            }

            // Open a file pointer in memory
            $callback = function () use ($list) {
                $file = fopen('php://output', 'w');
                fprintf($file, chr(0xEF).chr(0xBB).chr(0xBF));
                foreach ($list as $row) {
                    fputcsv($file, $row);
                }
                fclose($file);
            };

            return Response::stream($callback, 200, $headers);
        }
    }
}
