<?php

namespace App\Http\Controllers;

use App\Models\FamilyAid;
use Illuminate\Http\Request;

class FamilyAidController extends Controller
{
    /**
     * Display a listing of the resource.
     */
    public function index()
    {
        $data = FamilyAid::all();
        return view('admin.family_aid.index', compact('data'));
    }

    /**
     * Show the form for creating a new resource.
     */
    public function create()
    {
        return view('admin.family_aid.create');
    }

    /**
     * Store a newly created resource in storage.
     */
    public function store(Request $request)
    {
        // Validation rules
        $rules = [
            'custom_id' => 'required|string|max:255|unique:family_aid,custom_id',
            'mother_name' => 'required|string|max:255',
            'phone' => 'required|string|max:20',
            'type' => 'required|integer',
            'project' => 'nullable|string|max:255',
            'help_needed' => 'nullable|string|max:255',
            'help_needed_date' => 'required|date',
            'status' => 'required|string|max:50',
            'notes' => 'nullable|string|max:1000',
        ];

        if($request->type == 2){
            $rules["help_needed"] = 'required|string|max:255';
        }
        else{
            $rules["project"] = 'required|string|max:255';
        }

        // Custom error messages (optional, in Arabic for localization)
        $messages = [
            'custom_id.unique' => 'ترميز الدراسة موجود بالفعل.',
            'custom_id.required' => 'ترميز الدراسة مطلوب.',
            'mother_name.required' => 'اسم الأم مطلوب.',
            'phone.required' => 'رقم الهاتف مطلوب.',
            'phone.max' => 'رقم الهاتف لا يمكن أن يتجاوز 20 حرفًا.',
            'type.required' => 'نوع المساعدة مطلوب.',
            'type.integer' => 'نوع التنسيب يجب أن يكون رقماً صحيحاً.',
            'help_needed_date.required' => 'تاريخ طلب المساعدة مطلوب.',
            'help_needed_date.date' => 'تاريخ طلب المساعدة يجب أن يكون تاريخًا صالحًا.',
            'status.required' => 'حالة المساعدة مطلوبة.',
            'notes.string' => 'الملاحظات يجب أن تكون نصًا صالحًا.',
            'help_needed.required' => 'المساعدة المطلوبة مطلوبة',
            'project.required' => 'يرجى اختيار المشروع'
        ];

        // Validate the request
        $validated = $request->validate($rules, $messages);

        // Create the FamilyAid record
        $familyAid = FamilyAid::create($validated);

        if($familyAid){
            return redirect()->back()->with('success', "تم الإضافة بنجاح");
        }
    }


    /**
     * Display the specified resource.
     */
    public function show(string $id)
    {
        //
    }

    /**
     * Show the form for editing the specified resource.
     */
    public function edit(string $id)
    {
        $data = FamilyAid::find($id);
        if (!$data) {
            return redirect()->back();
        } else {
            return view('admin.family_aid.edit', compact('data'));
        }
    }

    /**
     * Update the specified resource in storage.
     */
    public function update(Request $request, string $id)
    {
        // Find the FamilyAid by ID
        $familyAid = FamilyAid::findOrFail($id);

        // Validation rules
        $rules = [
            'custom_id' => 'sometimes|string|max:255|unique:family_aid,custom_id,' . $familyAid->id,
            'mother_name' => 'required|string|max:255',
            'phone' => 'required|string|max:20',
            'type' => 'required|integer',
            'project' => 'nullable|string|max:255',
            'help_needed' => 'nullable|string|max:255',
            'help_needed_date' => 'required|date',
            'status' => 'required|string|max:50',
            'notes' => 'nullable|string|max:1000',
        ];

        if($request->type == 2){
            $rules["help_needed"] = 'required|string|max:255';
        }
        else{
            $rules["project"] = 'required|string|max:255';
        }

        // Custom error messages (optional, in Arabic for localization)
        $messages = [
            'custom_id.unique' => 'ترميز الدراسة موجود بالفعل.',
            'custom_id.required' => 'ترميز الدراسة مطلوب.',
            'mother_name.required' => 'اسم الأم مطلوب.',
            'phone.required' => 'رقم الهاتف مطلوب.',
            'phone.max' => 'رقم الهاتف لا يمكن أن يتجاوز 20 حرفًا.',
            'type.required' => 'نوع المساعدة مطلوب.',
            'type.integer' => 'نوع التنسيب يجب أن يكون رقماً صحيحاً.',
            'help_needed_date.required' => 'تاريخ طلب المساعدة مطلوب.',
            'help_needed_date.date' => 'تاريخ طلب المساعدة يجب أن يكون تاريخًا صالحًا.',
            'status.required' => 'حالة المساعدة مطلوبة.',
            'notes.string' => 'الملاحظات يجب أن تكون نصًا صالحًا.',
            'help_needed.required' => 'المساعدة المطلوبة مطلوبة',
            'project.required' => 'يرجى اختيار المشروع'
        ];

        // Validate the request
        $validated = $request->validate($rules, $messages);

        // Update the FamilyAid record with validated data
        $familyAid->update($validated);

        return redirect()->back()->with('success', 'تم التعديل بنجاح');
    }

    /**
     * Remove the specified resource from storage.
     */
    public function destroy(FamilyAid $family, Request $request)
    {
        $id = $request->id;
        $data = FamilyAid::find($id)->delete();
        if ($data) {
            echo json_encode(array("status" => "success"));
        } else {
            echo json_encode(array("status" => "failure"));
        }
    }
}
