<?php

namespace App\Http\Controllers;

use App\Models\Orphan;
use Illuminate\Http\Request;

class OrphanController extends Controller
{
    /**
     * Display a listing of the resource.
     */
    public function index()
    {
        $data = Orphan::where("status", "<>", 2)->get();

        return view('admin.orphan.index', compact('data'));
    }
    public function indexStopped()
    {
        $data = Orphan::where("status", 2)->get();

        return view('admin.orphan.index-stopped', compact("data"));
    }

    /**
     * Show the form for creating a new resource.
     */
    public function create()
    {
        return view('admin.orphan.create');
    }

    /**
     * Store a newly created resource in storage.
     */
    public function store(Request $request)
    {
        // Validation rules
        $rules = [
            'custom_id' => 'required|string|max:255|unique:orphans,custom_id',
            'child_name' => 'required|string|max:255',
            'mother_name' => 'required|string|max:255',
            'national_id' => 'required|string|max:20',
            'phone' => 'required|string|max:15',
            'address' => 'required|string|max:255',
            'birthday' => 'required|date',
            'bail_amount' => 'required|string|max:255',
            'additional_amount' => 'nullable|string|max:255',
            'orphan_type' => 'required|integer',
            'accept_docuware' => 'required|integer|in:0,1',
            'sponsorship_start_date' => 'required|date',
            'sponsorship_update_date' => 'nullable|date',
            'status' => 'required|integer|in:0,1,2',
            'is_visit' => 'required|integer|in:0,1',
            'statement_of_account' => 'nullable|string|max:255',
            'financial_disability_rate' => 'nullable|string|max:255',
        ];
        if($request->additional_amount > 0){
            $rules["exchangeـnotes"] = 'required|string|max:255';
        } else {
            $rules["exchangeـnotes"] = 'nullable|string|max:255';
        }
        if($request->is_visit == 1){
            $rules["visit_notes"] = 'required|string|max:255';
        } else {
            $rules["visit_notes"] = 'nullable|string|max:255';
        }
        if($request->status == 2){
            $rules["reason_for_suspension"] = 'required|string|max:255';
            $rules["date_of_suspension"] = 'required|date';
        } else {
            $rules["reason_for_suspension"] = 'nullable|string|max:255';
            $rules["date_of_suspension"] = 'nullable|date';
        }
        // Custom Arabic validation messages
        $messages = [
            'custom_id.unique' => 'ترميز الدراسة موجود بالفعل.',
            'custom_id.required' => 'ترميز الدراسة مطلوب.',
            'custom_id.string' => 'ترميز الدراسة يجب أن يكون نصاً.',
            'custom_id.max' => 'ترميز الدراسة يجب ألا يتجاوز 255 حرفاً.',
            'child_name.required' => 'اسم الطفل مطلوب.',
            'child_name.string' => 'اسم الطفل يجب أن يكون نصاً.',
            'child_name.max' => 'اسم الطفل يجب ألا يتجاوز 255 حرفاً.',
            'mother_name.required' => 'اسم الأم مطلوب.',
            'mother_name.string' => 'اسم الأم يجب أن يكون نصاً.',
            'mother_name.max' => 'اسم الأم يجب ألا يتجاوز 255 حرفاً.',
            'national_id.required' => 'الرقم الوطني مطلوب.',
            'national_id.string' => 'الرقم الوطني يجب أن يكون نصاً.',
            'national_id.max' => 'الرقم الوطني يجب ألا يتجاوز 20 حرفاً.',
            'phone.required' => 'رقم الهاتف مطلوب.',
            'phone.string' => 'رقم الهاتف يجب أن يكون نصاً.',
            'phone.max' => 'رقم الهاتف يجب ألا يتجاوز 15 حرفاً.',
            'address.required' => 'منطقة السكن مطلوب.',
            'address.string' => 'منطقة السكن يجب أن يكون نصاً.',
            'address.max' => 'منطقة السكن يجب ألا يتجاوز 255 حرفاً.',
            'birthday.required' => 'تاريخ ميلاد اليتيم مطلوب.',
            'birthday.date' => 'تاريخ ميلاد اليتيم يجب أن يكون تاريخاً صحيحاً.',
            'bail_amount.required' => 'مبلغ الكفالة مطلوب.',
            'bail_amount.string' => 'مبلغ الكفالة يجب أن يكون نصاً.',
            'bail_amount.max' => 'مبلغ الكفالة يجب ألا يتجاوز 255 حرفاً.',
            'additional_amount.string' => 'المبلغ الإضافي يجب أن يكون نصاً.',
            'additional_amount.max' => 'المبلغ الإضافي يجب ألا يتجاوز 255 حرفاً.',
            'exchangeـnotes.required' => "ملاحظات الصرف مطلوبة",
            'exchangeـnotes.string' => 'ملاحظات الصرف يجب أن تكون نصاً.',
            'exchangeـnotes.max' => 'ملاحظات الصرف يجب ألا تتجاوز 255 حرفاً.',
            'orphan_type.required' => 'تصنيف العائلة مطلوب.',
            'orphan_type.integer' => 'تصنيف العائلة يجب أن يكون رقماً.',
            'accept_docuware.required' => 'موافقة Docuware مطلوبة.',
            'accept_docuware.integer' => 'موافقة Docuware يجب أن تكون رقماً.',
            'accept_docuware.in' => 'موافقة Docuware يجب أن تكون 0 أو 1.',
            'sponsorship_start_date.required' => 'تاريخ بدء الكفالة مطلوب.',
            'sponsorship_start_date.date' => 'تاريخ بدء الكفالة يجب أن يكون تاريخاً صحيحاً.',
            'sponsorship_update_date.date' => 'تاريخ تحديث الكفالة يجب أن يكون تاريخاً صحيحاً.',
            'status.required' => 'حالة الكفالة مطلوبة.',
            'status.integer' => 'حالة الكفالة يجب أن تكون رقماً.',
            'status.in' => 'حالة الكفالة يجب أن تكون 0 أو 1.',
            'is_visit.required' => 'زيارة ميدانية مطلوبة.',
            'is_visit.integer' => 'زيارة ميدانية يجب أن تكون رقماً.',
            'is_visit.in' => 'زيارة ميدانية يجب أن تكون 0 أو 1.',
            'visit_notes.required' => 'ملاحظات الزيارة مطلوبة',
            'visit_notes.string' => 'ملاحظات الزيارة الميدانية يجب أن تكون نصاً.',
            'visit_notes.max' => 'ملاحظات الزيارة الميدانية يجب ألا تتجاوز 255 حرفاً.',
            'reason_for_suspension.required' => 'سبب الايقاف مطلوبة',
            'reason_for_suspension.string' => 'سبب الايقاف يجب أن تكون نصاً.',
            'reason_for_suspension.max' => 'سبب الايقاف يجب ألا تتجاوز 255 حرفاً.',
            'date_of_suspension.required' => 'سبب الايقاف مطلوب.',
            'date_of_suspension.date' => 'سبب الايقاف يجب أن يكون تاريخاً صحيحاً.',
            'statement_of_account.string' => 'بيان الحساب يجب أن يكون نصاً.',
            'statement_of_account.max' => 'بيان الحساب يجب ألا يتجاوز 255 حرفاً.',
            'financial_disability_rate.string' => 'نسبة العجز المادي يجب أن تكون نصاً.',
            'financial_disability_rate.max' => 'نسبة العجز المادي يجب ألا تتجاوز 255 حرفاً.',
        ];

        // Validate the request
        $validated = $request->validate($rules, $messages);

        // Create the donor
        $donor = Orphan::create($validated);

        if($donor){
            return redirect()->back()->with('success', "تم الإضافة بنجاح");
        }
    }

    /**
     * Display the specified resource.
     */
    public function show(string $id)
    {
        //
    }

    /**
     * Show the form for editing the specified resource.
     */
    public function edit(string $id)
    {
        $data = Orphan::find($id);
        if (!$data) {
            return redirect()->back();
        } else {
            return view('admin.orphan.edit', compact('data'));
        }
    }

    /**
     * Update the specified resource in storage.
     */
    public function update(Request $request, string $id)
    {
        // Find the FamilyAid by ID
        $orphan = Orphan::findOrFail($id);

        // Validation rules
        $rules = [
            'custom_id' => 'sometimes|string|max:255|unique:orphans,custom_id,' . $orphan->id,
            'child_name' => 'required|string|max:255',
            'mother_name' => 'required|string|max:255',
            'national_id' => 'required|string|max:20',
            'phone' => 'required|string|max:15',
            'address' => 'required|string|max:255',
            'birthday' => 'required|date',
            'bail_amount' => 'required|string|max:255',
            'additional_amount' => 'nullable|string|max:255',
            'orphan_type' => 'required|integer',
            'accept_docuware' => 'required|integer|in:0,1',
            'sponsorship_start_date' => 'required|date',
            'sponsorship_update_date' => 'nullable|date',
            'status' => 'required|integer|in:0,1,2',
            'is_visit' => 'required|integer|in:0,1',
            'statement_of_account' => 'nullable|string|max:255',
            'financial_disability_rate' => 'nullable|string|max:255',
        ];
        if($request->additional_amount > 0){
            $rules["exchangeـnotes"] = 'required|string|max:255';
        } else {
            $rules["exchangeـnotes"] = 'nullable|string|max:255';
        }
        if($request->is_visit == 1){
            $rules["visit_notes"] = 'required|string|max:255';
        } else {
            $rules["visit_notes"] = 'nullable|string|max:255';
        }
        if($request->status == 2){
            $rules["reason_for_suspension"] = 'required|string|max:255';
            $rules["date_of_suspension"] = 'required|date';
        } else {
            $rules["reason_for_suspension"] = 'nullable|string|max:255';
            $rules["date_of_suspension"] = 'nullable|date';
        }
        // Custom error messages (optional, in Arabic for localization)
        $messages = [
            'custom_id.unique' => 'ترميز الدراسة موجود بالفعل.',
            'custom_id.required' => 'ترميز الدراسة مطلوب.',
            'custom_id.string' => 'ترميز الدراسة يجب أن يكون نصاً.',
            'custom_id.max' => 'ترميز الدراسة يجب ألا يتجاوز 255 حرفاً.',
            'child_name.required' => 'اسم الطفل مطلوب.',
            'child_name.string' => 'اسم الطفل يجب أن يكون نصاً.',
            'child_name.max' => 'اسم الطفل يجب ألا يتجاوز 255 حرفاً.',
            'mother_name.required' => 'اسم الأم مطلوب.',
            'mother_name.string' => 'اسم الأم يجب أن يكون نصاً.',
            'mother_name.max' => 'اسم الأم يجب ألا يتجاوز 255 حرفاً.',
            'national_id.required' => 'الرقم الوطني مطلوب.',
            'national_id.string' => 'الرقم الوطني يجب أن يكون نصاً.',
            'national_id.max' => 'الرقم الوطني يجب ألا يتجاوز 20 حرفاً.',
            'phone.required' => 'رقم الهاتف مطلوب.',
            'phone.string' => 'رقم الهاتف يجب أن يكون نصاً.',
            'phone.max' => 'رقم الهاتف يجب ألا يتجاوز 15 حرفاً.',
            'address.required' => 'منطقة السكن مطلوب.',
            'address.string' => 'منطقة السكن يجب أن يكون نصاً.',
            'address.max' => 'منطقة السكن يجب ألا يتجاوز 255 حرفاً.',
            'birthday.required' => 'تاريخ ميلاد اليتيم مطلوب.',
            'birthday.date' => 'تاريخ ميلاد اليتيم يجب أن يكون تاريخاً صحيحاً.',
            'date_of_suspension.required' => 'سبب الايقاف مطلوب.',
            'date_of_suspension.date' => 'سبب الايقاف يجب أن يكون تاريخاً صحيحاً.',
            'bail_amount.required' => 'مبلغ الكفالة مطلوب.',
            'bail_amount.string' => 'مبلغ الكفالة يجب أن يكون نصاً.',
            'bail_amount.max' => 'مبلغ الكفالة يجب ألا يتجاوز 255 حرفاً.',
            'exchangeـnotes.required' => "ملاحظات الصرف مطلوبة",
            'additional_amount.string' => 'المبلغ الإضافي يجب أن يكون نصاً.',
            'additional_amount.max' => 'المبلغ الإضافي يجب ألا يتجاوز 255 حرفاً.',
            'exchangeـnotes.string' => 'ملاحظات الصرف يجب أن تكون نصاً.',
            'exchangeـnotes.max' => 'ملاحظات الصرف يجب ألا تتجاوز 255 حرفاً.',
            'orphan_type.required' => 'تصنيف العائلة مطلوب.',
            'orphan_type.integer' => 'تصنيف العائلة يجب أن يكون رقماً.',
            'accept_docuware.required' => 'موافقة Docuware مطلوبة.',
            'accept_docuware.integer' => 'موافقة Docuware يجب أن تكون رقماً.',
            'accept_docuware.in' => 'موافقة Docuware يجب أن تكون 0 أو 1.',
            'sponsorship_start_date.required' => 'تاريخ بدء الكفالة مطلوب.',
            'sponsorship_start_date.date' => 'تاريخ بدء الكفالة يجب أن يكون تاريخاً صحيحاً.',
            'sponsorship_update_date.date' => 'تاريخ تحديث الكفالة يجب أن يكون تاريخاً صحيحاً.',
            'status.required' => 'حالة الكفالة مطلوبة.',
            'status.integer' => 'حالة الكفالة يجب أن تكون رقماً.',
            'status.in' => 'حالة الكفالة يجب أن تكون 0 أو 1.',
            'is_visit.required' => 'زيارة ميدانية مطلوبة.',
            'is_visit.integer' => 'زيارة ميدانية يجب أن تكون رقماً.',
            'is_visit.in' => 'زيارة ميدانية يجب أن تكون 0 أو 1.',
            'visit_notes.required' => 'ملاحظات الزيارة مطلوبة',
            'visit_notes.string' => 'ملاحظات الزيارة الميدانية يجب أن تكون نصاً.',
            'visit_notes.max' => 'ملاحظات الزيارة الميدانية يجب ألا تتجاوز 255 حرفاً.',
            'reason_for_suspension.required' => 'سبب الايقاف مطلوبة',
            'reason_for_suspension.string' => 'سبب الايقاف يجب أن تكون نصاً.',
            'reason_for_suspension.max' => 'سبب الايقاف يجب ألا تتجاوز 255 حرفاً.',
            'statement_of_account.string' => 'بيان الحساب يجب أن يكون نصاً.',
            'statement_of_account.max' => 'بيان الحساب يجب ألا يتجاوز 255 حرفاً.',
            'financial_disability_rate.string' => 'نسبة العجز المادي يجب أن تكون نصاً.',
            'financial_disability_rate.max' => 'نسبة العجز المادي يجب ألا تتجاوز 255 حرفاً.',
        ];

        // Validate the request
        $validated = $request->validate($rules, $messages);

        // Update the FamilyAid record with validated data
        $orphan->update($validated);

        return redirect()->back()->with('success', 'تم التعديل بنجاح');
    }

    /**
     * Remove the specified resource from storage.
     */
    public function destroy(Orphan $orphan, Request $request)
    {
        $id = $request->id;
        $data = Orphan::find($id)->delete();
        if ($data) {
            echo json_encode(array("status" => "success"));
        } else {
            echo json_encode(array("status" => "failure"));
        }
    }
}
