<?php

namespace App\Http\Controllers;

use App\Models\ownCraft;
use App\Models\OwnTawjihi;
use App\Models\OwnUniversity;
use App\Models\StudyPlatform;
use Illuminate\Http\Request;

class OwnController extends Controller
{
    /**
     * Display a listing of the resource.
     */
    public function indexUniversity()
    {
        $data = OwnUniversity::all();
        return view('admin.own-university.index', compact('data'));
    }

    public function indexTawjihi()
    {
        $data = OwnTawjihi::all();
        return view('admin.own-tawjihi.index', compact('data'));
    }

    public function indexCraft()
    {
        $data = OwnCraft::all();
        return view('admin.own-craft.index', compact('data'));
    }

    /**
     * Show the form for creating a new resource.
     */
    public function createUniversity()
    {
        return view('admin.own-university.create');
    }

    public function createTawjihi()
    {
        $study_platforms = StudyPlatform::all();
        return view('admin.own-tawjihi.create', compact('study_platforms'));
    }

    public function createCraft()
    {
        return view('admin.own-craft.create');
    }


    /**
     * Store a newly created resource in storage.
     */
    public function storeUniversity(Request $request)
    {
        // Validation rules
        $rules = [
            'custom_id' => 'required|string|max:255|unique:own_university,custom_id',
            'scholarship_start_date' => 'required|date',
            'student_name' => 'required|string|max:255',
            'sponser_name' => 'required|string|max:255',
            'student_id' => 'required|string|max:255',
            'major' => 'required|string|max:255',
            'university_name' => 'required|string|max:255',
            'study_type' => 'required|integer',
            'study_year' => 'required|string|max:4',
            'hourlyـprice' => 'required|numeric|min:0',
            'registrationـfees' => 'required|numeric|min:0',
            'major_hours_count' => 'required|integer|min:0',
            'finished_hours_count' => 'required|integer|min:0',
            'total_financial_claims' => 'required|numeric|min:0',
            'notes' => 'nullable|string|max:1000',
        ];

        $messages = [
            'custom_id.required' => 'ترميز الدراسة مطلوب.',
            'custom_id.unique' => 'ترميز الدراسة موجود بالفعل.',
            'scholarship_start_date.required' => 'تاريخ بداية المنحة مطلوب.',
            'scholarship_start_date.date' => 'تاريخ بداية المنحة يجب أن يكون بتاريخ صحيح.',
            'student_name.required' => 'اسم الطالب مطلوب.',
            'student_name.string' => 'اسم الطالب يجب أن يكون نصًا.',
            'student_name.max' => 'اسم الطالب يجب ألا يتجاوز 255 حرفًا.',
            'sponser_name.required' => 'اسم الكفيل مطلوب.',
            'sponser_name.string' => 'اسم الكفيل يجب أن يكون نصًا.',
            'sponser_name.max' => 'اسم الكفيل يجب ألا يتجاوز 255 حرفًا.',
            'student_id.required' => 'الرقم الجامعي مطلوب.',
            'student_id.string' => 'الرقم الجامعي يجب أن يكون نصًا.',
            'student_id.max' => 'الرقم الجامعي يجب ألا يتجاوز 255 حرفًا.',
            'major.required' => 'التخصص مطلوب.',
            'major.string' => 'التخصص يجب أن يكون نصًا.',
            'major.max' => 'التخصص يجب ألا يتجاوز 255 حرفًا.',
            'university_name.required' => 'اسم الجامعة مطلوب.',
            'university_name.string' => 'اسم الجامعة يجب أن يكون نصًا.',
            'university_name.max' => 'اسم الجامعة يجب ألا يتجاوز 255 حرفًا.',
            'study_type.required' => 'نوع الدراسة مطلوب.',
            'study_type.integer' => 'نوع الدراسة يجب أن يكون رقماً صحيحاً.',
            'study_year.required' => 'السنة الدراسية مطلوبة.',
            'study_year.max' => 'السنة الدراسية يجب أن تكون بأربع خانات.',
            'hourlyـprice.required' => 'سعر الساعة مطلوب.',
            'hourlyـprice.numeric' => 'سعر الساعة يجب أن يكون عدداً.',
            'hourlyـprice.min' => 'سعر الساعة يجب أن يكون أكبر من أو يساوي 0.',
            'registrationـfees.required' => 'رسوم التسجيل مطلوبة.',
            'registrationـfees.numeric' => 'رسوم التسجيل يجب أن يكون عدداً.',
            'registrationـfees.min' => 'رسوم التسجيل يجب أن تكون أكبر من أو تساوي 0.',
            'major_hours_count.required' => 'عدد ساعات التخصص مطلوب.',
            'major_hours_count.integer' => 'عدد ساعات التخصص يجب أن يكون رقماً صحيحاً.',
            'major_hours_count.min' => 'عدد ساعات التخصص يجب أن يكون أكبر من أو يساوي 0.',
            'finished_hours_count.required' => 'عدد الساعات المقطوعة مطلوب.',
            'finished_hours_count.integer' => 'عدد الساعات المقطوعة يجب أن يكون رقماً صحيحاً.',
            'finished_hours_count.min' => 'عدد الساعات المقطوعة يجب أن يكون أكبر من أو يساوي 0.',
            'total_financial_claims.required' => 'مجموع المطالبات المالية مطلوبة.',
            'total_financial_claims.numeric' => 'مجموع المطالبات المالية يجب أن يكون عدداً.',
            'total_financial_claims.min' => 'مجموع المطالبات المالية يجب أن تكون أكبر من أو تساوي 0.',
            'notes.string' => 'الملاحظات يجب أن تكون نصًا.',
            'notes.required' => 'الملاحظات مطلوبة.',
        ];


        // Validate the request
        $validated = $request->validate($rules, $messages);

        // Create the OwnUniversity record
        $ownUniversity = OwnUniversity::create($validated);

        if($ownUniversity){
            return redirect()->back()->with('success', "تم الإضافة بنجاح");
        }
    }

    public function storeTawjihi(Request $request)
    {
        // Define validation rules
        $rules = [
            'custom_id' => 'required|string|max:255|unique:own_tawjihi,custom_id',
            'student_name' => 'required|string|max:255',
            'phone' => 'required|string|max:15',
            'city' => 'required|string|max:255',
            'major' => 'required|string|max:255',
            'total_subject' => 'required|integer|min:0',
            'price_for_semester' => 'required|numeric|min:0',
            'total_claims' => 'required|numeric|min:0',
            'notes' => 'nullable|string|max:1000',
        ];

        // Custom error messages in Arabic
        $messages = [
            'custom_id.required' => 'ترميز الدراسة مطلوب.',
            'custom_id.unique' => 'ترميز الدراسة موجود بالفعل.',
            'student_name.required' => 'اسم الطالب مطلوب.',
            'student_name.string' => 'اسم الطالب يجب أن يكون نصًا.',
            'student_name.max' => 'اسم الطالب يجب ألا يتجاوز 255 حرفًا.',
            'total_subject.required' => 'عدد المواد مطلوب.',
            'total_subject.integer' => 'عدد المواد يجب أن يكون رقماً صحيحاً.',
            'total_subject.min' => 'عدد المواد يجب أن يكون أكبر من أو يساوي 0.',
            'phone.required' => 'رقم الهاتف مطلوب.',
            'phone.string' => 'رقم الهاتف يجب أن يكون نصًا.',
            'phone.max' => 'رقم الهاتف يجب ألا يتجاوز 15 حرفًا.',
            'city.required' => 'المنطقة مطلوب.',
            'city.string' => 'المنطقة يجب أن يكون نصًا.',
            'city.max' => 'المنطقة يجب ألا يتجاوز 255 حرفًا.',
            'major.required' => 'التخصص مطلوب.',
            'major.string' => 'التخصص يجب أن يكون نصًا.',
            'major.max' => 'التخصص يجب ألا يتجاوز 255 حرفًا.',
            'price_for_semester.required' => 'المبلغ للفصل الواحد مطلوب.',
            'price_for_semester.numeric' => 'المبلغ للفصل الواحد يجب أن يكون عددًا.',
            'price_for_semester.min' => 'المبلغ للفصل الواحد يجب أن يكون أكبر من أو يساوي 0.',
            'total_claims.required' => 'المبلغ المطلوب مطلوب.',
            'total_claims.numeric' => 'المبلغ المطلوب يجب أن يكون عددًا.',
            'total_claims.min' => 'المبلغ المطلوب يجب أن يكون أكبر من أو يساوي 0.',
            'notes.string' => 'الملاحظات يجب أن تكون نصًا.',
            'notes.required' => 'الملاحظات مطلوبة.',
        ];

        $materials = [];
        for($i = 1; $i <= $request->total_subject; $i++){
            $studySite = $request->input('study_site' . $i);
            $nameMaterial = $request->input('name_material' . $i);
            $studyPrice = $request->input('study_price' . $i);
            if($studySite && $nameMaterial && $studyPrice){
                $materials[$i] = ["study_site" => $studySite, "name_material" => $nameMaterial, "study_price" => $studyPrice];
            }
        }

        // Validate the request
        $validated = $request->validate($rules, $messages);
        $validated["materials"] = json_encode($materials);
        // Create the OwnTawjihi record
        $ownTawjihi = OwnTawjihi::create($validated);

        if($ownTawjihi){
            return redirect()->back()->with('success', "تم الإضافة بنجاح");
        }
    }

    public function storeCraft(Request $request)
    {
        // Define validation rules
        $rules = [
            'custom_id' => 'required|string|max:255|unique:own_craft,custom_id',
            'scholarship_start_date' => 'required|date',
            'student_name' => 'required|string|max:255',
            'sponser_name' => 'required|string|max:255',
            'institution_name' => 'required|string|max:255',
            'major' => 'required|string|max:255',
            'study_year' => 'required|string|max:4',
            'fee' => 'required|numeric|min:0',
            'major_hours_count' => 'required|integer|min:0',
            'finished_hours_count' => 'required|integer|min:0',
            'total_financial_claims' => 'required|numeric|min:0',
            'notes' => 'nullable|string|max:1000',
        ];

        // Custom error messages in Arabic
        $messages = [
            'custom_id.required' => 'ترميز الدراسة مطلوب.',
            'custom_id.unique' => 'ترميز الدراسة موجود بالفعل.',
            'student_name.required' => 'اسم الطالب مطلوب.',
            'student_name.string' => 'اسم الطالب يجب أن يكون نصًا.',
            'student_name.max' => 'اسم الطالب يجب ألا يتجاوز 255 حرفًا.',
            'sponser_name.required' => 'اسم الكفيل مطلوب.',
            'sponser_name.string' => 'اسم الكفيل يجب أن يكون نصًا.',
            'sponser_name.max' => 'اسم الكفيل يجب ألا يتجاوز 255 حرفًا.',
            'institution_name.required' => 'اسم المؤسسة مطلوب.',
            'institution_name.string' => 'اسم المؤسسة يجب أن يكون نصًا.',
            'institution_name.max' => 'اسم المؤسسة يجب ألا يتجاوز 255 حرفًا.',
            'major.required' => 'التخصص مطلوب.',
            'major.string' => 'التخصص يجب أن يكون نصًا.',
            'major.max' => 'التخصص يجب ألا يتجاوز 255 حرفًا.',
            'study_year.required' => 'سنة الدراسة مطلوبة.',
            'study_year.max' => 'سنة الدراسة يجب أن تكون بأربع خانات.',
            'scholarship_start_date.required' => 'تاريخ بداية المنحة مطلوب.',
            'scholarship_start_date.date' => 'تاريخ بداية المنحة يجب أن يكون بتاريخ صحيح.',
            'major_hours_count.required' => 'عدد ساعات التخصص مطلوب.',
            'major_hours_count.integer' => 'عدد ساعات التخصص يجب أن يكون رقماً صحيحاً.',
            'major_hours_count.min' => 'عدد ساعات التخصص يجب أن يكون أكبر من أو يساوي 0.',
            'finished_hours_count.required' => 'عدد الساعات المقطوعة مطلوب.',
            'finished_hours_count.integer' => 'عدد الساعات المقطوعة يجب أن يكون رقماً صحيحاً.',
            'finished_hours_count.min' => 'عدد الساعات المقطوعة يجب أن يكون أكبر من أو يساوي 0.',
            'fee.required' => 'الرسوم مطلوبة.',
            'fee.numeric' => 'الرسوب يجب أن يجب أن يكون عدداً.',
            'fee.min' => 'الرسوم يجب أن تكون أكبر من أو تساوي 0.',
            'total_financial_claims.required' => 'مجموع المطالبات المالية مطلوبة.',
            'total_financial_claims.numeric' => 'مجموع المطالبات المالية يجب أن يجب أن يكون عدداً.',
            'total_financial_claims.min' => 'مجموع المطالبات المالية يجب أن تكون أكبر من أو تساوي 0.',
            'notes.string' => 'الملاحظات يجب أن تكون نصًا.',
            'notes.required' => 'الملاحظات مطلوبة.',
        ];

        // Validate the request with the rules and messages
        $validated = $request->validate($rules, $messages);

        // Create the OwnCraft record with the validated data
        $ownCraft = OwnCraft::create($validated);

        if($ownCraft){
            return redirect()->back()->with('success', "تم الإضافة بنجاح");
        }
    }

    /**
     * Show the form for editing the specified resource.
     */
    public function editUniversity(string $id)
    {
        $data = OwnUniversity::find($id);
        if (!$data) {
            return redirect()->back();
        } else {
            return view('admin.own-university.edit', compact('data'));
        }
    }

    public function editTawjihi(string $id)
    {
        $study_platforms = StudyPlatform::all();
        $data = OwnTawjihi::find($id);
        if (!$data) {
            return redirect()->back();
        } else {
            $data->materials = json_decode($data->materials, 1);
            return view('admin.own-tawjihi.edit', compact('data', 'study_platforms'));
        }
    }

    public function editCraft(string $id)
    {
        $data = OwnCraft::find($id);
        if (!$data) {
            return redirect()->back();
        } else {
            return view('admin.own-craft.edit', compact('data'));
        }
    }

    /**
     * Update the specified resource in storage.
     */
    public function updateUniversity(Request $request, string $id)
    {
        // Find the OwnUniversity by ID
        $ownUniversity = OwnUniversity::findOrFail($id);

        // Validation rules
        $rules = [
            'custom_id' => 'sometimes|string|max:255|unique:own_university,custom_id,' . $ownUniversity->id,
            'scholarship_start_date' => 'required|date',
            'student_name' => 'sometimes|string|max:255',
            'sponser_name' => 'sometimes|string|max:255',
            'student_id' => 'sometimes|string|max:255',
            'major' => 'sometimes|string|max:255',
            'university_name' => 'required|string|max:255',
            'study_type' => 'required|integer',
            'study_year' => 'required|string|max:4',
            'hourlyـprice' => 'required|numeric|min:0',
            'registrationـfees' => 'required|numeric|min:0',
            'major_hours_count' => 'required|integer|min:0',
            'finished_hours_count' => 'required|integer|min:0',
            'total_financial_claims' => 'required|numeric|min:0',
            'notes' => 'nullable|string|max:1000',
        ];

        // Custom error messages in Arabic
        $messages = [

            'custom_id.required' => 'ترميز الدراسة مطلوب.',
            'custom_id.unique' => 'ترميز الدراسة موجود بالفعل.',
            'scholarship_start_date.required' => 'تاريخ بداية المنحة مطلوب.',
            'scholarship_start_date.date' => 'تاريخ بداية المنحة يجب أن يكون بتاريخ صحيح.',
            'student_name.required' => 'اسم الطالب مطلوب.',
            'student_name.string' => 'اسم الطالب يجب أن يكون نصًا.',
            'student_name.max' => 'اسم الطالب يجب ألا يتجاوز 255 حرفًا.',
            'sponser_name.required' => 'اسم الكفيل مطلوب.',
            'sponser_name.string' => 'اسم الكفيل يجب أن يكون نصًا.',
            'sponser_name.max' => 'اسم الكفيل يجب ألا يتجاوز 255 حرفًا.',
            'student_id.required' => 'الرقم الجامعي مطلوب.',
            'student_id.string' => 'الرقم الجامعي يجب أن يكون نصًا.',
            'student_id.max' => 'الرقم الجامعي يجب ألا يتجاوز 255 حرفًا.',
            'major.required' => 'التخصص مطلوب.',
            'major.string' => 'التخصص يجب أن يكون نصًا.',
            'major.max' => 'التخصص يجب ألا يتجاوز 255 حرفًا.',
            'university_name.required' => 'اسم الجامعة مطلوب.',
            'university_name.string' => 'اسم الجامعة يجب أن يكون نصًا.',
            'university_name.max' => 'اسم الجامعة يجب ألا يتجاوز 255 حرفًا.',
            'study_type.required' => 'نوع الدراسة مطلوب.',
            'study_type.integer' => 'نوع الدراسة يجب أن يكون رقماً صحيحاً.',
            'study_year.required' => 'السنة الدراسية مطلوبة.',
            'study_year.max' => 'السنة الدراسية يجب أن تكون بأربع خانات.',
            'hourlyـprice.required' => 'سعر الساعة مطلوب.',
            'hourlyـprice.numeric' => 'سعر الساعة يجب أن يكون عدداً.',
            'hourlyـprice.min' => 'سعر الساعة يجب أن يكون أكبر من أو يساوي 0.',
            'registrationـfees.required' => 'رسوم التسجيل مطلوبة.',
            'registrationـfees.numeric' => 'رسوم التسجيل يجب أن يكون عدداً.',
            'registrationـfees.min' => 'رسوم التسجيل يجب أن تكون أكبر من أو تساوي 0.',
            'major_hours_count.required' => 'عدد ساعات التخصص مطلوب.',
            'major_hours_count.integer' => 'عدد ساعات التخصص يجب أن يكون رقماً صحيحاً.',
            'major_hours_count.min' => 'عدد ساعات التخصص يجب أن يكون أكبر من أو يساوي 0.',
            'finished_hours_count.required' => 'عدد الساعات المقطوعة مطلوب.',
            'finished_hours_count.integer' => 'عدد الساعات المقطوعة يجب أن يكون رقماً صحيحاً.',
            'finished_hours_count.min' => 'عدد الساعات المقطوعة يجب أن يكون أكبر من أو يساوي 0.',
            'total_financial_claims.required' => 'مجموع المطالبات المالية مطلوبة.',
            'total_financial_claims.numeric' => 'مجموع المطالبات المالية يجب أن يكون عدداً.',
            'total_financial_claims.min' => 'مجموع المطالبات المالية يجب أن تكون أكبر من أو تساوي 0.',
            'notes.string' => 'الملاحظات يجب أن تكون نصًا.',
            'notes.required' => 'الملاحظات مطلوبة.',
        ];

        // Validate the request
        $validated = $request->validate($rules, $messages);

        // Update the OwnUniversity record
        $ownUniversity->update($validated);

        return redirect()->back()->with('success', 'تم التعديل بنجاح');
    }

    public function updateTawjihi(Request $request, string $id)
    {
        // Find the existing record by ID
        $ownTawjihi = OwnTawjihi::findOrFail($id);

        // Define validation rules
        $rules = [
            'custom_id' => 'required|string|max:255|unique:own_tawjihi,custom_id,' . $id,
            'student_name' => 'required|string|max:255',
            'phone' => 'required|string|max:15',
            'city' => 'required|string|max:255',
            'major' => 'required|string|max:255',
            'total_subject' => 'required|integer|min:0',
            'price_for_semester' => 'required|numeric|min:0',
            'total_claims' => 'required|numeric|min:0',
            'notes' => 'nullable|string|max:1000',
        ];

        // Custom error messages in Arabic
        $messages = [
            'custom_id.required' => 'ترميز الدراسة مطلوب.',
            'custom_id.unique' => 'ترميز الدراسة موجود بالفعل.',
            'student_name.required' => 'اسم الطالب مطلوب.',
            'student_name.string' => 'اسم الطالب يجب أن يكون نصًا.',
            'student_name.max' => 'اسم الطالب يجب ألا يتجاوز 255 حرفًا.',
            'total_subject.required' => 'عدد المواد مطلوب.',
            'total_subject.integer' => 'عدد المواد يجب أن يكون رقماً صحيحاً.',
            'total_subject.min' => 'عدد المواد يجب أن يكون أكبر من أو يساوي 0.',
            'phone.required' => 'رقم الهاتف مطلوب.',
            'phone.string' => 'رقم الهاتف يجب أن يكون نصًا.',
            'phone.max' => 'رقم الهاتف يجب ألا يتجاوز 15 حرفًا.',
            'city.required' => 'المنطقة مطلوب.',
            'city.string' => 'المنطقة يجب أن يكون نصًا.',
            'city.max' => 'المنطقة يجب ألا يتجاوز 255 حرفًا.',
            'major.required' => 'التخصص مطلوب.',
            'major.string' => 'التخصص يجب أن يكون نصًا.',
            'major.max' => 'التخصص يجب ألا يتجاوز 255 حرفًا.',
            'price_for_semester.required' => 'المبلغ للفصل الواحد مطلوب.',
            'price_for_semester.numeric' => 'المبلغ للفصل الواحد يجب أن يكون عددًا.',
            'price_for_semester.min' => 'المبلغ للفصل الواحد يجب أن يكون أكبر من أو يساوي 0.',
            'total_claims.required' => 'المبلغ المطلوب مطلوب.',
            'total_claims.numeric' => 'المبلغ المطلوب يجب أن يكون عددًا.',
            'total_claims.min' => 'المبلغ المطلوب يجب أن يكون أكبر من أو يساوي 0.',
            'notes.string' => 'الملاحظات يجب أن تكون نصًا.',
            'notes.required' => 'الملاحظات مطلوبة.',
        ];

        $materials = [];
        for($i = 1; $i <= $request->total_subject; $i++){
            $studySite = $request->input('study_site' . $i);
            $nameMaterial = $request->input('name_material' . $i);
            $studyPrice = $request->input('study_price' . $i);
            if($studySite && $nameMaterial && $studyPrice){
                $materials[$i] = ["study_site" => $studySite, "name_material" => $nameMaterial, "study_price" => $studyPrice];
            }
        }

        // Validate the request
        $validated = $request->validate($rules, $messages);
        $validated["materials"] = json_encode($materials);

        // Update the existing record with the validated data
        $ownTawjihi->update($validated);

        return redirect()->back()->with('success', 'تم التعديل بنجاح');
    }

    public function updateCraft(Request $request, string $id)
    {
        // Find the existing record by ID
        $ownCraft = OwnCraft::findOrFail($id);

        // Define validation rules for update
        $rules = [
            'custom_id' => 'required|string|max:255|unique:own_craft,custom_id,' . $id,
            'scholarship_start_date' => 'required|date',
            'student_name' => 'required|string|max:255',
            'sponser_name' => 'required|string|max:255',
            'institution_name' => 'required|string|max:255',
            'major' => 'required|string|max:255',
            'study_year' => 'required|string|max:4',
            'fee' => 'required|numeric|min:0',
            'major_hours_count' => 'required|integer|min:0',
            'finished_hours_count' => 'required|integer|min:0',
            'total_financial_claims' => 'required|numeric|min:0',
            'notes' => 'nullable|string|max:1000',
        ];

        // Custom error messages in Arabic
        $messages = [
            'custom_id.required' => 'ترميز الدراسة مطلوب.',
            'custom_id.unique' => 'ترميز الدراسة موجود بالفعل.',
            'student_name.required' => 'اسم الطالب مطلوب.',
            'student_name.string' => 'اسم الطالب يجب أن يكون نصًا.',
            'student_name.max' => 'اسم الطالب يجب ألا يتجاوز 255 حرفًا.',
            'sponser_name.required' => 'اسم الكفيل مطلوب.',
            'sponser_name.string' => 'اسم الكفيل يجب أن يكون نصًا.',
            'sponser_name.max' => 'اسم الكفيل يجب ألا يتجاوز 255 حرفًا.',
            'institution_name.required' => 'اسم المؤسسة مطلوب.',
            'institution_name.string' => 'اسم المؤسسة يجب أن يكون نصًا.',
            'institution_name.max' => 'اسم المؤسسة يجب ألا يتجاوز 255 حرفًا.',
            'major.required' => 'التخصص مطلوب.',
            'major.string' => 'التخصص يجب أن يكون نصًا.',
            'major.max' => 'التخصص يجب ألا يتجاوز 255 حرفًا.',
            'study_year.required' => 'سنة الدراسة مطلوبة.',
            'study_year.max' => 'سنة الدراسة يجب أن تكون بأربع خانات.',
            'scholarship_start_date.required' => 'تاريخ بداية المنحة مطلوب.',
            'scholarship_start_date.date' => 'تاريخ بداية المنحة يجب أن يكون بتاريخ صحيح.',
            'major_hours_count.required' => 'عدد ساعات التخصص مطلوب.',
            'major_hours_count.integer' => 'عدد ساعات التخصص يجب أن يكون رقماً صحيحاً.',
            'major_hours_count.min' => 'عدد ساعات التخصص يجب أن يكون أكبر من أو يساوي 0.',
            'finished_hours_count.required' => 'عدد الساعات المقطوعة مطلوب.',
            'finished_hours_count.integer' => 'عدد الساعات المقطوعة يجب أن يكون رقماً صحيحاً.',
            'finished_hours_count.min' => 'عدد الساعات المقطوعة يجب أن يكون أكبر من أو يساوي 0.',
            'fee.required' => 'الرسوم مطلوبة.',
            'fee.numeric' => 'الرسوب يجب أن يجب أن يكون عدداً.',
            'fee.min' => 'الرسوم يجب أن تكون أكبر من أو تساوي 0.',
            'total_financial_claims.required' => 'مجموع المطالبات المالية مطلوبة.',
            'total_financial_claims.numeric' => 'مجموع المطالبات المالية يجب أن يجب أن يكون عدداً.',
            'total_financial_claims.min' => 'مجموع المطالبات المالية يجب أن تكون أكبر من أو تساوي 0.',
            'notes.string' => 'الملاحظات يجب أن تكون نصًا.',
            'notes.required' => 'الملاحظات مطلوبة.',
        ];

        // Validate the request with the rules and messages
        $validated = $request->validate($rules, $messages);

        // Update the existing record with the validated data
        $ownCraft->update($validated);

        return redirect()->back()->with('success', 'تم التعديل بنجاح');
    }
    /**
     * Remove the specified resource from storage.
     */
    public function destroyUniversity(OwnUniversity $student, Request $request)
    {
        $id = $request->id;
        $data = OwnUniversity::find($id)->delete();
        if ($data) {
            echo json_encode(array("status" => "success"));
        } else {
            echo json_encode(array("status" => "failure"));
        }
    }

    public function destroyCraft(OwnCraft $student, Request $request)
    {
        $id = $request->id;
        $data = OwnCraft::find($id)->delete();
        if ($data) {
            echo json_encode(array("status" => "success"));
        } else {
            echo json_encode(array("status" => "failure"));
        }
    }

    public function destroyTawjihi(OwnTawjihi $student, Request $request)
    {
        $id = $request->id;
        $data = OwnTawjihi::find($id)->delete();
        if ($data) {
            echo json_encode(array("status" => "success"));
        } else {
            echo json_encode(array("status" => "failure"));
        }
    }
}
