<?php

namespace App\Http\Controllers;

use App\Models\StudyPlatform;
use Illuminate\Http\Request;

class StudyPlatformController extends Controller
{
    /**
     * Display a listing of the resource.
     */
    public function index()
    {
        $data = StudyPlatform::all();
        return view('admin.study_platforms.index', compact('data'));
    }

    /**
     * Show the form for creating a new resource.
     */
    public function create()
    {
        return view('admin.study_platforms.create');
    }

    /**
     * Store a newly created resource in storage.
     */
    public function store(Request $request)
    {
        // Validation rules
        $rules = [
            'name' => 'required|string|max:255',
        ];

        // Custom Arabic validation messages
        $messages = [
            'name.required' => 'اسم المنصة مطلوب.',
        ];

        // Validate the request
        $validated = $request->validate($rules, $messages);

        // Create the donor
        $donor = StudyPlatform::create($validated);

        if($donor){
            return redirect()->back()->with('success', "تم الإضافة بنجاح");
        }
    }

    /**
     * Display the specified resource.
     */
    public function show(string $id)
    {
        //
    }

    /**
     * Show the form for editing the specified resource.
     */
    public function edit(string $id)
    {
        $data = StudyPlatform::find($id);
        if (!$data) {
            return redirect()->back();
        } else {
            return view('admin.study_platforms.edit', compact('data'));
        }
    }

    /**
     * Update the specified resource in storage.
     */
    public function update(Request $request, string $id)
    {
        // Find the donor by ID
        $donor = StudyPlatform::findOrFail($id);

        // Validation rules
        $rules = [
            'name' => 'required|string|max:255',
        ];

        // Custom Arabic validation messages
        $messages = [
            'name.required' => 'اسم المنصة مطلوب.',
        ];

        // Validate the request
        $validated = $request->validate($rules, $messages);

        // Update the donor with validated data
        $donor->update($validated);

        return redirect()->back()->with('success', 'تم التعديل بنجاح');
    }

    /**
     * Remove the specified resource from storage.
     */
    public function destroy(string $id, Request $request)
    {
        $id = $request->id;
        $data = StudyPlatform::find($id)->delete();
        if ($data) {
            echo json_encode(array("status" => "success"));
        } else {
            echo json_encode(array("status" => "failure"));
        }
    }
}
