<?php

namespace App\Http\Controllers;

use App\Models\TakeaChance;
use Illuminate\Http\Request;

class TakeaChanceController extends Controller
{
    /**
     * Display a listing of the resource.
     */
    public function index()
    {
        $data = TakeaChance::where('type', 1)->get();
        return view('admin.takeachance.index', compact('data'));
    }

    /**
     * Display a listing of the resource.
     */
    public function indexPrejodkom()
    {
        $data = TakeaChance::where('type', 2)->get();
        return view('admin.prejodkom.index', compact('data'));
    }

    /**
     * Display a listing of the resource.
     */
    public function indexJodkom()
    {
        $data = TakeaChance::where('type', 3)->get();
        return view('admin.jodkom.index', compact('data'));
    }

    /**
     * Show the form for creating a new resource.
     */
    public function create()
    {
        return view('admin.takeachance.create');
    }

    /**
     * Store a newly created resource in storage.
     */
    public function store(Request $request)
    {
        // Validation rules
        $rules = [
            'custom_id' => 'required|string|max:255|unique:takeachance,custom_id',
            'name' => 'required|string|max:255',
            'city' => 'required|string|max:255',
            'phone' => 'required|string|max:20',
            'age' => 'required|integer|min:0|max:100',
            'academic_achievement' => 'required|string|max:255',
            'class' => 'required|string|max:50',
        ];

        // Custom validation messages in Arabic
        $messages = [
            'custom_id.required' => 'ترميز الدراسة مطلوب.',
            'custom_id.unique' => 'ترميز الدراسة موجود بالفعل.',
            'custom_id.max' => 'ترميز الدراسة يجب ألا يتجاوز 255 حرفًا.',
            'name.required' => 'يجب إدخال اسم الطالب.',
            'name.string' => 'اسم الطالب يجب أن يكون نصًا.',
            'name.max' => 'اسم الطالب يجب ألا يتجاوز 255 حرفًا.',
            'city.required' => 'يجب إدخال منطقة السكن.',
            'city.string' => 'منطقة السكن يجب أن تكون نصًا.',
            'city.max' => 'منطقة السكن يجب ألا تتجاوز 255 حرفًا.',
            'phone.required' => 'يجب إدخال رقم الهاتف.',
            'phone.string' => 'رقم الهاتف يجب أن يكون نصًا.',
            'phone.max' => 'رقم الهاتف يجب ألا يتجاوز 20 حرفًا.',
            'age.required' => 'يجب إدخال العمر.',
            'age.integer' => 'العمر يجب أن يكون عددًا صحيحًا.',
            'age.max' => 'العمر يجب أن يكون أقل من 100 سنة.',
            'academic_achievement.required' => 'يجب إدخال التحصيل الاكاديمي.',
            'academic_achievement.string' => 'التحصيل الاكاديمي يجب أن يكون نصًا.',
            'academic_achievement.max' => 'التحصيل الاكاديمي يجب ألا يتجاوز 255 حرفًا.',
            'class.required' => 'يجب إدخال الصف.',
            'class.string' => 'الصف يجب أن يكون نصًا.',
            'class.max' => 'الصف يجب ألا يتجاوز 50 حرفًا.',
        ];


        // Validate the request
        $validated = $request->validate($rules, $messages);

        $takeachance = TakeaChance::create($validated);

        if($takeachance){
            return redirect()->back()->with('success', "تم الإضافة بنجاح");
        }
    }

    /**
     * Display the specified resource.
     */
    public function show(string $id)
    {
        //
    }

    /**
     * Show the form for editing the specified resource.
     */
    public function edit(string $id)
    {
        $data = TakeaChance::where(["id" => $id, "type" => 1])->first();
        if (!$data) {
            return redirect()->back();
        } else {
            return view('admin.takeachance.edit', compact('data'));
        }
    }

    /**
     * Show the form for editing the specified resource.
     */
    public function editPreJodkom(string $id)
    {
        $data = TakeaChance::where(["id" => $id, "type" => 2])->first();
        if (!$data) {
            return redirect()->back();
        } else {
            return view('admin.prejodkom.edit', compact('data'));
        }
    }

    /**
     * Update the specified resource in storage.
     */
    public function update(Request $request, string $id)
    {
        // Find the donor by ID
        $takeachance = TakeaChance::findOrFail($id);

        // Validation rules
        $rules = [
            'custom_id' => 'required|string|max:255|unique:takeachance,custom_id,' . $takeachance->id,
            'name' => 'required|string|max:255',
            'city' => 'required|string|max:255',
            'phone' => 'required|string|max:20',
            'age' => 'required|integer|min:0|max:100',
            'academic_achievement' => 'required|string|max:255',
            'class' => 'required|string|max:50',
        ];

        // Custom Arabic validation messages
        $messages = [
            'custom_id.required' => 'ترميز الدراسة مطلوب.',
            'custom_id.unique' => 'ترميز الدراسة موجود بالفعل.',
            'custom_id.max' => 'ترميز الدراسة يجب ألا يتجاوز 255 حرفًا.',
            'name.required' => 'يجب إدخال اسم الطالب.',
            'name.string' => 'اسم الطالب يجب أن يكون نصًا.',
            'name.max' => 'اسم الطالب يجب ألا يتجاوز 255 حرفًا.',
            'city.required' => 'يجب إدخال منطقة السكن.',
            'city.string' => 'منطقة السكن يجب أن تكون نصًا.',
            'city.max' => 'منطقة السكن يجب ألا تتجاوز 255 حرفًا.',
            'phone.required' => 'يجب إدخال رقم الهاتف.',
            'phone.string' => 'رقم الهاتف يجب أن يكون نصًا.',
            'phone.max' => 'رقم الهاتف يجب ألا يتجاوز 20 حرفًا.',
            'age.required' => 'يجب إدخال العمر.',
            'age.integer' => 'العمر يجب أن يكون عددًا صحيحًا.',
            'age.max' => 'العمر يجب أن يكون أقل من 100 سنة.',
            'academic_achievement.required' => 'يجب إدخال التحصيل الاكاديمي.',
            'academic_achievement.string' => 'التحصيل الاكاديمي يجب أن يكون نصًا.',
            'academic_achievement.max' => 'التحصيل الاكاديمي يجب ألا يتجاوز 255 حرفًا.',
            'class.required' => 'يجب إدخال الصف.',
            'class.string' => 'الصف يجب أن يكون نصًا.',
            'class.max' => 'الصف يجب ألا يتجاوز 50 حرفًا.',
        ];

        // Validate the request
        $validated = $request->validate($rules, $messages);

        $takeachance->update($validated);

        return redirect()->back()->with('success', 'تم التعديل بنجاح');
    }

    public function updatePrejodkom(Request $request, string $id)
    {
        // Find the donor by ID
        $takeachance = TakeaChance::findOrFail($id);

        // Validation rules
        $rules = [
            'skills' => 'required|string|max:1000',
            'courses' => 'required|string|max:1000',
            'additional_info' => 'nullable|string|max:1000',
            'notes' => 'nullable|string|max:1000',
        ];

        // Custom Arabic validation messages
        $messages = [
            'skills.string' => 'المهارات يجب أن تكون نصًا.',
            'skills.required' => 'المهارات مطلوبة.',
            'courses.string' => 'الدورات يجب أن تكون نصًا.',
            'courses.required' => 'الدورات مطلوبة.',
            'additional_info.string' => 'معلومات إضافية يجب أن تكون نصًا.',
            'notes.string' => 'الملاحظات يجب أن تكون نصًا.',
        ];

        // Validate the request
        $validated = $request->validate($rules, $messages);

        $takeachance->update($validated);

        return redirect()->back()->with('success', 'تم التعديل بنجاح');
    }
    /**
     * Remove the specified resource from storage.
     */
    public function destroy(TakeaChance $takeaChance, Request $request)
    {
        $id = $request->id;
        $data = TakeaChance::find($id)->delete();
        if ($data) {
            echo json_encode(array("status" => "success"));
        } else {
            echo json_encode(array("status" => "failure"));
        }
    }

    public function save_recommendation(Request $request){
        if(isset($request->id)){
            $id = $request->id;
            $recommendation_desc = isset($request->data) ? $request->data : '';
            $decline_reason = isset($request->decline_reason) ? $request->decline_reason : '';
            $accepted = isset($request->accepted) ? $request->accepted : '';
            $data = TakeaChance::findOrFail($id);
            if($accepted == 1){
                $data->type = 2;
                $data->recommendation_desc = $recommendation_desc;
                $data->decline_reason = "";
            }
            else{
                $data->type = 1;
                $data->recommendation_desc = "";
                $data->decline_reason = $decline_reason;
            }

            if ($data->save()) {
                echo json_encode(array("status" => "success"));
            } else {
                echo json_encode(array("status" => "failure"));
            }
        }
    }

    public function acceptStudent(Request $request)
    {
        if(isset($request->id)){
            $id = $request->id;
            $data = TakeaChance::findOrFail($id);
            $data->type = 3;
            if ($data->save()) {
                echo json_encode(array("status" => "success"));
            } else {
                echo json_encode(array("status" => "failure"));
            }
        }
    }
}
