<?php

namespace App\Models;

use Illuminate\Database\Eloquent\Factories\HasFactory;
use Illuminate\Database\Eloquent\Model;
use Illuminate\Database\Eloquent\SoftDeletes;
use Spatie\MediaLibrary\HasMedia;
use Spatie\MediaLibrary\InteractsWithMedia;

class CaseModel extends Model implements HasMedia
{
    use HasFactory, SoftDeletes, InteractsWithMedia;

    // The table associated with the model
    protected $table = 'cases';

    protected $hidden = ['media'];

    protected $appends = ['attachments'];

    // The attributes that are mass assignable
    protected $fillable = [
        'case_type',
        'name',
        'parent_name',
        'address',
        'phone',
        'custom_id',
        'created_case_date',
        'updated_case_date',
        'case_desc',
        'status'
    ];

    // Define the children relationship
    public function children()
    {
        return $this->hasMany(CaseChild::class, 'case_id');
    }

    // Define the children relationship
    public function childrenMarried()
    {
        return $this->hasMany(CaseChildMarried::class, 'case_id');
    }

    // Define the children relationship
    public function caseOthers()
    {
        return $this->hasMany(CaseOther::class, 'case_id');
    }

    public function father()
    {
        return $this->hasOne(CaseFather::class, 'case_id');
    }

    public function mother()
    {
        return $this->hasOne(CaseMother::class, 'case_id');
    }

    public function property()
    {
        return $this->hasOne(CaseProperty::class, 'case_id');
    }

    public function income()
    {
        return $this->hasMany(CaseIncome::class, 'case_id');
    }

    public function expenses()
    {
        return $this->hasMany(CaseExpenses::class, 'case_id');
    }

    public function marketing()
    {
        return $this->hasOne(CaseMarketing::class, 'case_id');
    }
}
