@extends('layouts.admin.add')
@section('title')تعديل معلومات الطالب@endsection

@section('content')

@include('includes.admin.header' , ['label_name' => 'تعديل معلومات الطالب' ])

<div class="row">
    <div class="col-12">
        <div class="widget-rounded-circle card-box d-flex justify-content-between">
            <form class='w-100' action="{{ route('own.updateTawjihi', $data) }}" method="POST" enctype="multipart/form-data">
                @csrf
                @method('PUT')
                <div class="row">
                    <div class="col-md-12">
                        <div class="form-row">
                            <div class="form-group col-md-12">
                                @if ($errors->any())
                                <div class="alert alert-danger">
                                    <ul class='ml-3 mb-0'>
                                        @foreach ($errors->all() as $error)
                                        <li>{{ $error }}</li>
                                        @endforeach
                                    </ul>
                                </div>
                                @endif
                                @if (session('success'))
                                <div class="alert alert-success">
                                    {{ session('success') }}
                                </div>
                                @endif
                            </div>
                            <div class="form-group col-md-4">
                                <label for="custom_id">ترميز الدراسة</label>
                                <input type="text" id="custom_id" name="custom_id" placeholder='ترميز الدراسة' value="{{ $data->custom_id }}" class="form-control">
                            </div>
                            <div class="form-group col-md-4">
                                <label for="student_name">اسم الطالب</label>
                                <input type="text" id="student_name" name="student_name" placeholder='اسم الطالب' value="{{ $data->student_name }}" class="form-control">
                            </div>
                            <div class="form-group col-md-4">
                                <label for="phone">رقم الهاتف</label>
                                <input type="text" id="phone" name="phone" placeholder='رقم الهاتف' value="{{ $data->phone }}" class="form-control">
                            </div>
                            <div class="form-group col-md-4">
                                <label for="city">المنطقة</label>
                                <input type="text" id="city" name="city" placeholder='المنطقة' value="{{ $data->city }}" class="form-control">
                            </div>
                            <div class="form-group col-md-4">
                                <label for="major">التخصص</label>
                                <input type="text" id="major" name="major" placeholder='التخصص' value="{{ $data->major }}" class="form-control">
                            </div>
                            <div class="form-group col-md-4">
                                <label for="price_for_semester">المبلغ للفصل الواحد</label>
                                <input type="number" step="any" id="price_for_semester" name="price_for_semester" placeholder='المبلغ للفصل الواحد' value="{{ $data->price_for_semester }}" class="form-control">
                            </div>
                            <div class="form-group col-md-4">
                                <label for="total_claims">المبلغ المطلوب</label>
                                <input type="number" step="any" id="total_claims" name="total_claims" placeholder='المبلغ المطلوب' value="{{ $data->total_claims }}" class="form-control">
                            </div>
                            <div class="form-group col-md-4">
                                <label for="total_subject">عدد المواد</label>
                                <input type="number" step="any" id="total_subject" name="total_subject" placeholder='عدد المواد' value="{{ $data->total_subject }}" class="form-control">
                            </div>
                            <div class="form-group col-md">
                                <label for="notes">الملاحظات</label>
                                <textarea class="form-control" rows="1" name="notes" id="notes">{{ $data->notes }}</textarea>
                            </div>
                        </div>
                        <div class="form-row">
                            <div class="form-group col-12">
                                <table class="table">
                                    <thead>
                                    <tr>
                                        <th>المنصة</th>
                                        <th>اسم المادة</th>
                                        <th>السعر</th>
                                    </tr>
                                    </thead>
                                    <tbody>
                                    @for ($i = 1; $i <= 10; $i++)
                                        @php
                                            $show = false;
                                            if($i == 1){
                                                $show = true;
                                            }
                                        @endphp
                                        <tr class="d-none" id="subject_row_{{ $i }}">
                                            <td>
                                                <select class="form-control" name="study_site{{ $i }}" id="study_site{{ $i }}">
                                                    <option value="">إختر</option>
                                                    @foreach($study_platforms as $platform)
                                                        <option value="{{ $platform->id }}" @if(isset($data->materials[$i]) && $data->materials[$i]["study_site"] == $platform->id) SELECTED @endif>{{ $platform->name }}</option>
                                                    @endforeach
                                                </select>
                                            </td>
                                            <td>
                                                <input type="text" id="name_material{{ $i }}" name="name_material{{ $i }}" placeholder='اسم المادة' value="{{ isset($data->materials[$i]) ? $data->materials[$i]["name_material"] : ''}}" class="form-control">
                                            </td>
                                            <td>
                                                <input type="number" step="any" min="0" id="study_price{{ $i }}" name="study_price{{ $i }}" placeholder='السعر' value="{{ isset($data->materials[$i]) ? $data->materials[$i]["study_price"] : '' }}" class="form-control">
                                            </td>
                                        </tr>
                                    @endfor
                                    </tbody>
                                </table>

                            </div>
                        </div>
                        <div class="form-row">
                            <div class="form-group col-md-12 text-right">
                                <button class='btn btn-primary px-4'>حفظ</button>
                            </div>
                        </div>
                    </div>
                </div>
            </form>
        </div>
    </div>
</div>
@endsection

@section('jsCode')
    <script>
        $(document).ready(function() {
            // Function to calculate the sum of all study prices
            function calculateTotalClaims() {
                let totalClaims = 0;

                // Loop through all the study price input fields
                for (let i = 1; i <= 10; i++) {
                    let price = parseFloat($("#study_price" + i).val()) || 0; // Get value of each price or 0 if not a number
                    totalClaims += price; // Add to total
                }

                // Set the total claims to the total_claims field
                $("#total_claims").val(totalClaims.toFixed(2)); // Update with two decimal places
                if(totalClaims > 150){
                    Swal.fire({
                        title: "تنبيه!",
                        text: "مجموع اسعار البطاقات تجاوز الحد الاعلى 150 دينار",
                        type: "question"
                    });
                }
            }

            // Listen for changes in the price fields and recalculate total
            $("input[id^='study_price']").on("input", function() {
                calculateTotalClaims();
            });

            // Call calculateTotalClaims on page load to set the initial value
            calculateTotalClaims();
        });
    </script>
    <script>
        $(document).ready(function() {
            // Function to display rows based on total_subject input
            function updateRowsVisibility() {
                var totalSubjects = parseInt($('#total_subject').val()) || 0; // Get the value of total_subject

                // Loop through all rows (1 to 10) and hide/show based on total_subject
                for (let i = 1; i <= 10; i++) {
                    if (i <= totalSubjects) {
                        $('#subject_row_' + i).removeClass('d-none'); // Show row
                    } else {
                        $('#subject_row_' + i).addClass('d-none'); // Hide row
                    }
                }
            }

            // Listen for changes in the total_subject field
            $('#total_subject').on('input', function() {
                updateRowsVisibility(); // Update rows visibility whenever the total_subject changes
            });

            // Call updateRowsVisibility on page load to set the initial state
            updateRowsVisibility();
        });
    </script>
@endsection

