<?php

use App\Http\Controllers\CaseController;
use App\Http\Controllers\DonorController;
use App\Http\Controllers\ExcelController;
use App\Http\Controllers\FamilyAidController;
use App\Http\Controllers\MarketingController;
use App\Http\Controllers\OrphanController;
use App\Http\Controllers\OwnController;
use App\Http\Controllers\StudyPlatformController;
use App\Http\Controllers\TakeaChanceController;
use App\Http\Controllers\UploadController;
use Illuminate\Support\Facades\Route;
use App\Http\Controllers\AdminController;
use App\Http\Controllers\HomeController;

/*
|--------------------------------------------------------------------------
| Web Routes
|--------------------------------------------------------------------------
|
| Here is where you can register web routes for your application. These
| routes are loaded by the RouteServiceProvider and all of them will
| be assigned to the "web" middleware group. Make something great!
|
*/

Auth::routes([
    'register' => false, // Registration Routes...
    'reset' => false, // Password Reset Routes...
    'verify' => false, // Email Verification Routes...
]);

/* Admins */
Route::prefix('/admin/users')->group(function () {
    Route::get('/', [
        AdminController::class,
        'index'
    ])->middleware('master')->name('admin.index');
    Route::get('/create', [
        AdminController::class,
        'create'
    ])->middleware('master')->name('admin.create');
    Route::post('/store', [
        AdminController::class,
        'store'
    ])->middleware('master')->name('admin.store');
    Route::get('/delete/{id}', [
        AdminController::class,
        'destroy'
    ])->middleware('master')->name('admin.destroy');
    Route::get('/edit/{id}', [
        AdminController::class,
        'edit'
    ])->middleware('master')->name('admin.edit');
    Route::put('/update/{id}', [
        AdminController::class,
        'update'
    ])->middleware('master')->name('admin.update');
});

/* Admins */
Route::prefix('/admin/cases')->group(function () {
    Route::get('/', [
        CaseController::class,
        'index'
    ])->middleware('master')->name('case.index');
    Route::get('/updates', [
        CaseController::class,
        'updateCases'
    ])->middleware('master')->name('case.updateCases');
    Route::get('/create', [
        CaseController::class,
        'create'
    ])->middleware('master')->name('case.create');
    Route::post('/store', [
        CaseController::class,
        'store'
    ])->middleware('master')->name('case.store');
    Route::get('/edit/{id}', [
        CaseController::class,
        'edit'
    ])->middleware('master')->name('case.edit');
    Route::put('/update/{id}', [
        CaseController::class,
        'update'
    ])->middleware('master')->name('case.update');
    Route::post('/change-status', [
        CaseController::class,
        'update_status'
    ])->middleware('master')->name('case.change_status');
    Route::get('/study/{id}', [
        CaseController::class,
        'generatePdf'
    ])->middleware('master')->name('case.generatePdf');
});

/* Orphans */
Route::prefix('/admin/orphans')->group(function () {
    Route::get('/', [
        OrphanController::class,
        'index'
    ])->middleware('master')->name('orphan.index');
    Route::get('/create', [
        OrphanController::class,
        'create'
    ])->middleware('master')->name('orphan.create');
    Route::post('/store', [
        OrphanController::class,
        'store'
    ])->middleware('master')->name('orphan.store');
    Route::get('/edit/{id}', [
        OrphanController::class,
        'edit'
    ])->middleware('master')->name('orphan.edit');
    Route::put('/update/{id}', [
        OrphanController::class,
        'update'
    ])->middleware('master')->name('orphan.update');
    Route::get('/delete/{id}', [
        OrphanController::class,
        'destroy'
    ])->middleware('master')->name('orphan.destroy');
    Route::get('/marketing', [
        MarketingController::class,
        'index'
    ])->middleware('master')->name('marketing.index');
});

/* Donor */
Route::prefix('/admin/donors')->group(function () {
    Route::get('/', [
        DonorController::class,
        'index'
    ])->middleware('master')->name('donor.index');
    Route::get('/create', [
        DonorController::class,
        'create'
    ])->middleware('master')->name('donor.create');
    Route::post('/store', [
        DonorController::class,
        'store'
    ])->middleware('master')->name('donor.store');
    Route::get('/edit/{id}', [
        DonorController::class,
        'edit'
    ])->middleware('master')->name('donor.edit');
    Route::put('/update/{id}', [
        DonorController::class,
        'update'
    ])->middleware('master')->name('donor.update');
    Route::get('/delete/{id}', [
        DonorController::class,
        'destroy'
    ])->middleware('master')->name('donor.destroy');
    Route::post('/store-and-orphan', [
        DonorController::class,
        'storeAndOrphan'
    ])->middleware('master')->name('donor.storeAndOrphan');
});

Route::prefix('/admin/study-platforms')->group(function () {
    Route::get('/', [
        StudyPlatformController::class,
        'index'
    ])->middleware('master')->name('study_platform.index');
    Route::get('/create', [
        StudyPlatformController::class,
        'create'
    ])->middleware('master')->name('study_platform.create');
    Route::post('/store', [
        StudyPlatformController::class,
        'store'
    ])->middleware('master')->name('study_platform.store');
    Route::get('/edit/{id}', [
        StudyPlatformController::class,
        'edit'
    ])->middleware('master')->name('study_platform.edit');
    Route::put('/update/{id}', [
        StudyPlatformController::class,
        'update'
    ])->middleware('master')->name('study_platform.update');
    Route::get('/delete/{id}', [
        StudyPlatformController::class,
        'destroy'
    ])->middleware('master')->name('study_platform.destroy');
});

Route::prefix('/admin/aid-for-families')->group(function () {
    Route::get('/', [
        FamilyAidController::class,
        'index'
    ])->middleware('master')->name('familyAid.index');
    Route::get('/create', [
        FamilyAidController::class,
        'create'
    ])->middleware('master')->name('familyAid.create');
    Route::post('/store', [
        FamilyAidController::class,
        'store'
    ])->middleware('master')->name('familyAid.store');
    Route::get('/edit/{id}', [
        FamilyAidController::class,
        'edit'
    ])->middleware('master')->name('familyAid.edit');
    Route::put('/update/{id}', [
        FamilyAidController::class,
        'update'
    ])->middleware('master')->name('familyAid.update');
    Route::get('/delete/{id}', [
        FamilyAidController::class,
        'destroy'
    ])->middleware('master')->name('familyAid.destroy');
});

Route::prefix('/admin/own-university')->group(function () {
    Route::get('/', [
        OwnController::class,
        'indexUniversity'
    ])->middleware('master')->name('own.indexUniversity');
    Route::get('/create', [
        OwnController::class,
        'createUniversity'
    ])->middleware('master')->name('own.createUniversity');
    Route::post('/store', [
        OwnController::class,
        'storeUniversity'
    ])->middleware('master')->name('own.storeUniversity');
    Route::get('/edit/{id}', [
        OwnController::class,
        'editUniversity'
    ])->middleware('master')->name('own.editUniversity');
    Route::put('/update/{id}', [
        OwnController::class,
        'updateUniversity'
    ])->middleware('master')->name('own.updateUniversity');
    Route::get('/delete/{id}', [
        OwnController::class,
        'destroyUniversity'
    ])->middleware('master')->name('own.destroyUniversity');
});

Route::prefix('/admin/own-tawjihi')->group(function () {
    Route::get('/', [
        OwnController::class,
        'indexTawjihi'
    ])->middleware('master')->name('own.indexTawjihi');
    Route::get('/create', [
        OwnController::class,
        'createTawjihi'
    ])->middleware('master')->name('own.createTawjihi');
    Route::post('/store', [
        OwnController::class,
        'storeTawjihi'
    ])->middleware('master')->name('own.storeTawjihi');
    Route::get('/edit/{id}', [
        OwnController::class,
        'editTawjihi'
    ])->middleware('master')->name('own.editTawjihi');
    Route::put('/update/{id}', [
        OwnController::class,
        'updateTawjihi'
    ])->middleware('master')->name('own.updateTawjihi');
    Route::get('/delete/{id}', [
        OwnController::class,
        'destroyTawjihi'
    ])->middleware('master')->name('own.destroyTawjihi');
});

Route::prefix('/admin/own-craft')->group(function () {
    Route::get('/', [
        OwnController::class,
        'indexCraft'
    ])->middleware('master')->name('own.indexCraft');
    Route::get('/create', [
        OwnController::class,
        'createCraft'
    ])->middleware('master')->name('own.createCraft');
    Route::post('/store', [
        OwnController::class,
        'storeCraft'
    ])->middleware('master')->name('own.storeCraft');
    Route::get('/edit/{id}', [
        OwnController::class,
        'editCraft'
    ])->middleware('master')->name('own.editCraft');
    Route::put('/update/{id}', [
        OwnController::class,
        'updateCraft'
    ])->middleware('master')->name('own.updateCraft');
    Route::get('/delete/{id}', [
        OwnController::class,
        'destroyCraft'
    ])->middleware('master')->name('own.destroyCraft');
});

Route::prefix('/admin/take-a-chance')->group(function () {
    Route::get('/', [
        TakeaChanceController::class,
        'index'
    ])->middleware('master')->name('takeachance.index');
    Route::get('/create', [
        TakeaChanceController::class,
        'create'
    ])->middleware('master')->name('takeachance.create');
    Route::post('/store', [
        TakeaChanceController::class,
        'store'
    ])->middleware('master')->name('takeachance.store');
    Route::get('/edit/{id}', [
        TakeaChanceController::class,
        'edit'
    ])->middleware('master')->name('takeachance.edit');
    Route::put('/update/{id}', [
        TakeaChanceController::class,
        'update'
    ])->middleware('master')->name('takeachance.update');
    Route::get('/delete/{id}', [
        TakeaChanceController::class,
        'destroy'
    ])->middleware('master')->name('takeachance.destroy');
    Route::post('/send-to-recommendation', [
        TakeaChanceController::class,
        'save_recommendation'
    ])->middleware('master')->name('takeachance.save_recommendation');

    Route::get('/prejodkom', [
        TakeaChanceController::class,
        'indexPrejodkom'
    ])->middleware('master')->name('takeachance.index_prejodkom');
    Route::get('/prejodkom/edit/{id}', [
        TakeaChanceController::class,
        'editPreJodkom'
    ])->middleware('master')->name('takeachance.edit_prejodkom');
    Route::put('/prejodkom/update/{id}', [
        TakeaChanceController::class,
        'updatePrejodkom'
    ])->middleware('master')->name('takeachance.update_prejodkom');
    Route::post('/send-jodkom', [
        TakeaChanceController::class,
        'acceptStudent'
    ])->middleware('master')->name('takeachance.accept_student');

    Route::get('/jodkom', [
        TakeaChanceController::class,
        'indexJodkom'
    ])->middleware('master')->name('takeachance.index_jodkom');
    Route::get('/jodkom/{id}', [
        TakeaChanceController::class,
        'showJodkom'
    ])->middleware('master')->name('takeachance.show_jodkom');

});

Route::prefix('/admin/attachments')->group(function () {
    Route::post('/store', [
        UploadController::class,
        'store'
    ])->middleware('master')->name('uploader.store');
    Route::get('/own-university/{id}', [
        UploadController::class,
        'uploadUniversity'
    ])->middleware('master')->name('uploader.university');
    Route::get('/own-craft/{id}', [
        UploadController::class,
        'uploadCraft'
    ])->middleware('master')->name('uploader.craft');
    Route::get('/own-tawjihi/{id}', [
        UploadController::class,
        'uploadTawjihi'
    ])->middleware('master')->name('uploader.tawjihi');
    Route::get('/cases/{id}', [
        UploadController::class,
        'uploadCases'
    ])->middleware('master')->name('uploader.cases');
});

Route::prefix('/admin/disbursement')->group(function () {
    Route::get('/excel', [
        ExcelController::class,
        'index'
    ])->middleware('auth')->name('excel.index');
    Route::get('/excel/generate', [
        ExcelController::class,
        'generate'
    ])->middleware('auth')->name('excel.generate');
    Route::get('/excel/save', [
        ExcelController::class,
        'save'
    ])->middleware('auth')->name('excel.save');
    Route::get('/excel/{id}', [
        ExcelController::class,
        'show'
    ])->middleware('auth')->name('excel.show');
    Route::get('/excel/{id}/download', [
        ExcelController::class,
        'downloadCSV'
    ])->middleware('auth')->name('excel.download');
});


Route::get('/admin/stopped-orphans', [
    OrphanController::class,
    'indexStopped'
])->middleware('master')->name('orphans.stopped');

Route::get('/admin/dashboard', [
    HomeController::class,
    'index'
])->middleware('auth')->name('dashboard');
